
var CanvasKitInit = (() => {
  var _scriptName = import.meta.url;
  
  return (
function(moduleArg = {}) {
  var moduleRtn;

var q=moduleArg,ca,da,fa=new Promise((a,b)=>{ca=a;da=b}),ha="object"==typeof window,ia="function"==typeof importScripts;
(function(a){a.Ud=a.Ud||[];a.Ud.push(function(){a.MakeSWCanvasSurface=function(b){var c=b,e="undefined"!==typeof OffscreenCanvas&&c instanceof OffscreenCanvas;if(!("undefined"!==typeof HTMLCanvasElement&&c instanceof HTMLCanvasElement||e||(c=document.getElementById(b),c)))throw"Canvas with id "+b+" was not found";if(b=a.MakeSurface(c.width,c.height))b.re=c;return b};a.MakeCanvasSurface||(a.MakeCanvasSurface=a.MakeSWCanvasSurface);a.MakeSurface=function(b,c){var e={width:b,height:c,colorType:a.ColorType.RGBA_8888,
alphaType:a.AlphaType.Unpremul,colorSpace:a.ColorSpace.SRGB},f=b*c*4,h=a._malloc(f);if(e=a.Surface._makeRasterDirect(e,h,4*b))e.re=null,e.Te=b,e.Qe=c,e.Re=f,e.Ae=h,e.getCanvas().clear(a.TRANSPARENT);return e};a.MakeRasterDirectSurface=function(b,c,e){return a.Surface._makeRasterDirect(b,c.byteOffset,e)};a.Surface.prototype.flush=function(b){a.Rd(this.Qd);this._flush();if(this.re){var c=new Uint8ClampedArray(a.HEAPU8.buffer,this.Ae,this.Re);c=new ImageData(c,this.Te,this.Qe);b?this.re.getContext("2d").putImageData(c,
0,0,b[0],b[1],b[2]-b[0],b[3]-b[1]):this.re.getContext("2d").putImageData(c,0,0)}};a.Surface.prototype.dispose=function(){this.Ae&&a._free(this.Ae);this.delete()};a.Rd=a.Rd||function(){};a.ue=a.ue||function(){return null}})})(q);
(function(a){a.Ud=a.Ud||[];a.Ud.push(function(){function b(h,l,p){return h&&h.hasOwnProperty(l)?h[l]:p}function c(h){var l=ja(ka);ka[l]=h;return l}function e(h,l,p,t){h.bindTexture(h.TEXTURE_2D,l);t||p.alphaType!==a.AlphaType.Premul||h.pixelStorei(h.UNPACK_PREMULTIPLY_ALPHA_WEBGL,!0);return l}function f(h,l,p){p||l.alphaType!==a.AlphaType.Premul||h.pixelStorei(h.UNPACK_PREMULTIPLY_ALPHA_WEBGL,!1);h.bindTexture(h.TEXTURE_2D,null)}a.GetWebGLContext=function(h,l){if(!h)throw"null canvas passed into makeWebGLContext";
var p={alpha:b(l,"alpha",1),depth:b(l,"depth",1),stencil:b(l,"stencil",8),antialias:b(l,"antialias",0),premultipliedAlpha:b(l,"premultipliedAlpha",1),preserveDrawingBuffer:b(l,"preserveDrawingBuffer",0),preferLowPowerToHighPerformance:b(l,"preferLowPowerToHighPerformance",0),failIfMajorPerformanceCaveat:b(l,"failIfMajorPerformanceCaveat",0),enableExtensionsByDefault:b(l,"enableExtensionsByDefault",1),explicitSwapControl:b(l,"explicitSwapControl",0),renderViaOffscreenBackBuffer:b(l,"renderViaOffscreenBackBuffer",
0)};p.majorVersion=l&&l.majorVersion?l.majorVersion:"undefined"!==typeof WebGL2RenderingContext?2:1;if(p.explicitSwapControl)throw"explicitSwapControl is not supported";h=la(h,p);if(!h)return 0;oa(h);z.ce.getExtension("WEBGL_debug_renderer_info");return h};a.deleteContext=function(h){z===pa[h]&&(z=null);"object"==typeof JSEvents&&JSEvents.tf(pa[h].ce.canvas);pa[h]&&pa[h].ce.canvas&&(pa[h].ce.canvas.Oe=void 0);pa[h]=null};a._setTextureCleanup({deleteTexture:function(h,l){var p=ka[l];p&&pa[h].ce.deleteTexture(p);
ka[l]=null}});a.MakeWebGLContext=function(h){if(!this.Rd(h))return null;var l=this._MakeGrContext();if(!l)return null;l.Qd=h;var p=l.delete.bind(l);l["delete"]=function(){a.Rd(this.Qd);p()}.bind(l);return z.Ce=l};a.MakeGrContext=a.MakeWebGLContext;a.GrDirectContext.prototype.getResourceCacheLimitBytes=function(){a.Rd(this.Qd);this._getResourceCacheLimitBytes()};a.GrDirectContext.prototype.getResourceCacheUsageBytes=function(){a.Rd(this.Qd);this._getResourceCacheUsageBytes()};a.GrDirectContext.prototype.releaseResourcesAndAbandonContext=
function(){a.Rd(this.Qd);this._releaseResourcesAndAbandonContext()};a.GrDirectContext.prototype.setResourceCacheLimitBytes=function(h){a.Rd(this.Qd);this._setResourceCacheLimitBytes(h)};a.MakeOnScreenGLSurface=function(h,l,p,t,v,y){if(!this.Rd(h.Qd))return null;l=void 0===v||void 0===y?this._MakeOnScreenGLSurface(h,l,p,t):this._MakeOnScreenGLSurface(h,l,p,t,v,y);if(!l)return null;l.Qd=h.Qd;return l};a.MakeRenderTarget=function(){var h=arguments[0];if(!this.Rd(h.Qd))return null;if(3===arguments.length){var l=
this._MakeRenderTargetWH(h,arguments[1],arguments[2]);if(!l)return null}else if(2===arguments.length){if(l=this._MakeRenderTargetII(h,arguments[1]),!l)return null}else return null;l.Qd=h.Qd;return l};a.MakeWebGLCanvasSurface=function(h,l,p){l=l||null;var t=h,v="undefined"!==typeof OffscreenCanvas&&t instanceof OffscreenCanvas;if(!("undefined"!==typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||v||(t=document.getElementById(h),t)))throw"Canvas with id "+h+" was not found";h=this.GetWebGLContext(t,
p);if(!h||0>h)throw"failed to create webgl context: err "+h;h=this.MakeWebGLContext(h);l=this.MakeOnScreenGLSurface(h,t.width,t.height,l);return l?l:(l=t.cloneNode(!0),t.parentNode.replaceChild(l,t),l.classList.add("ck-replaced"),a.MakeSWCanvasSurface(l))};a.MakeCanvasSurface=a.MakeWebGLCanvasSurface;a.Surface.prototype.makeImageFromTexture=function(h,l){a.Rd(this.Qd);h=c(h);if(l=this._makeImageFromTexture(this.Qd,h,l))l.le=h;return l};a.Surface.prototype.makeImageFromTextureSource=function(h,l,p){l||=
{height:a.se(h),width:a.te(h),colorType:a.ColorType.RGBA_8888,alphaType:p?a.AlphaType.Premul:a.AlphaType.Unpremul};l.colorSpace||(l.colorSpace=a.ColorSpace.SRGB);a.Rd(this.Qd);var t=z.ce;p=e(t,t.createTexture(),l,p);2===z.version?t.texImage2D(t.TEXTURE_2D,0,t.RGBA,l.width,l.height,0,t.RGBA,t.UNSIGNED_BYTE,h):t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,h);f(t,l);this._resetContext();return this.makeImageFromTexture(p,l)};a.Surface.prototype.updateTextureFromSource=function(h,l,p){if(h.le){a.Rd(this.Qd);
var t=h.getImageInfo(),v=z.ce,y=e(v,ka[h.le],t,p);2===z.version?v.texImage2D(v.TEXTURE_2D,0,v.RGBA,a.te(l),a.se(l),0,v.RGBA,v.UNSIGNED_BYTE,l):v.texImage2D(v.TEXTURE_2D,0,v.RGBA,v.RGBA,v.UNSIGNED_BYTE,l);f(v,t,p);this._resetContext();ka[h.le]=null;h.le=c(y);t.colorSpace=h.getColorSpace();l=this._makeImageFromTexture(this.Qd,h.le,t);p=h.Pd.Sd;v=h.Pd.Wd;h.Pd.Sd=l.Pd.Sd;h.Pd.Wd=l.Pd.Wd;l.Pd.Sd=p;l.Pd.Wd=v;l.delete();t.colorSpace.delete()}};a.MakeLazyImageFromTextureSource=function(h,l,p){l||={height:a.se(h),
width:a.te(h),colorType:a.ColorType.RGBA_8888,alphaType:p?a.AlphaType.Premul:a.AlphaType.Unpremul};l.colorSpace||(l.colorSpace=a.ColorSpace.SRGB);var t={makeTexture:function(){var v=z,y=v.ce,C=e(y,y.createTexture(),l,p);2===v.version?y.texImage2D(y.TEXTURE_2D,0,y.RGBA,l.width,l.height,0,y.RGBA,y.UNSIGNED_BYTE,h):y.texImage2D(y.TEXTURE_2D,0,y.RGBA,y.RGBA,y.UNSIGNED_BYTE,h);f(y,l,p);return c(C)},freeSrc:function(){}};"VideoFrame"===h.constructor.name&&(t.freeSrc=function(){h.close()});return a.Image._makeFromGenerator(l,
t)};a.Rd=function(h){return h?oa(h):!1};a.ue=function(){return z&&z.Ce&&!z.Ce.isDeleted()?z.Ce:null}})})(q);
(function(a){function b(g){return(f(255*g[3])<<24|f(255*g[0])<<16|f(255*g[1])<<8|f(255*g[2])<<0)>>>0}function c(g){if(g&&g._ck)return g;if(g instanceof Float32Array){for(var d=Math.floor(g.length/4),k=new Uint32Array(d),m=0;m<d;m++)k[m]=b(g.slice(4*m,4*(m+1)));return k}if(g instanceof Uint32Array)return g;if(g instanceof Array&&g[0]instanceof Float32Array)return g.map(b)}function e(g){if(void 0===g)return 1;var d=parseFloat(g);return g&&-1!==g.indexOf("%")?d/100:d}function f(g){return Math.round(Math.max(0,
Math.min(g||0,255)))}function h(g,d){d&&d._ck||a._free(g)}function l(g,d,k){if(!g||!g.length)return K;if(g&&g._ck)return g.byteOffset;var m=a[d].BYTES_PER_ELEMENT;k||=a._malloc(g.length*m);a[d].set(g,k/m);return k}function p(g){var d={Zd:K,count:g.length,colorType:a.ColorType.RGBA_F32};if(g instanceof Float32Array)d.Zd=l(g,"HEAPF32"),d.count=g.length/4;else if(g instanceof Uint32Array)d.Zd=l(g,"HEAPU32"),d.colorType=a.ColorType.RGBA_8888;else if(g instanceof Array){if(g&&g.length){for(var k=a._malloc(16*
g.length),m=0,r=k/4,u=0;u<g.length;u++)for(var x=0;4>x;x++)a.HEAPF32[r+m]=g[u][x],m++;g=k}else g=K;d.Zd=g}else throw"Invalid argument to copyFlexibleColorArray, Not a color array "+typeof g;return d}function t(g){if(!g)return K;var d=aa.toTypedArray();if(g.length){if(6===g.length||9===g.length)return l(g,"HEAPF32",P),6===g.length&&a.HEAPF32.set(Wc,6+P/4),P;if(16===g.length)return d[0]=g[0],d[1]=g[1],d[2]=g[3],d[3]=g[4],d[4]=g[5],d[5]=g[7],d[6]=g[12],d[7]=g[13],d[8]=g[15],P;throw"invalid matrix size";
}if(void 0===g.m11)throw"invalid matrix argument";d[0]=g.m11;d[1]=g.m21;d[2]=g.m41;d[3]=g.m12;d[4]=g.m22;d[5]=g.m42;d[6]=g.m14;d[7]=g.m24;d[8]=g.m44;return P}function v(g){if(!g)return K;var d=Y.toTypedArray();if(g.length){if(16!==g.length&&6!==g.length&&9!==g.length)throw"invalid matrix size";if(16===g.length)return l(g,"HEAPF32",ma);d.fill(0);d[0]=g[0];d[1]=g[1];d[3]=g[2];d[4]=g[3];d[5]=g[4];d[7]=g[5];d[10]=1;d[12]=g[6];d[13]=g[7];d[15]=g[8];6===g.length&&(d[12]=0,d[13]=0,d[15]=1);return ma}if(void 0===
g.m11)throw"invalid matrix argument";d[0]=g.m11;d[1]=g.m21;d[2]=g.m31;d[3]=g.m41;d[4]=g.m12;d[5]=g.m22;d[6]=g.m32;d[7]=g.m42;d[8]=g.m13;d[9]=g.m23;d[10]=g.m33;d[11]=g.m43;d[12]=g.m14;d[13]=g.m24;d[14]=g.m34;d[15]=g.m44;return ma}function y(g,d){return l(g,"HEAPF32",d||ea)}function C(g,d,k,m){var r=Fa.toTypedArray();r[0]=g;r[1]=d;r[2]=k;r[3]=m;return ea}function H(g){for(var d=new Float32Array(4),k=0;4>k;k++)d[k]=a.HEAPF32[g/4+k];return d}function I(g,d){return l(g,"HEAPF32",d||V)}function Q(g,d){return l(g,
"HEAPF32",d||ub)}a.Color=function(g,d,k,m){void 0===m&&(m=1);return a.Color4f(f(g)/255,f(d)/255,f(k)/255,m)};a.ColorAsInt=function(g,d,k,m){void 0===m&&(m=255);return(f(m)<<24|f(g)<<16|f(d)<<8|f(k)<<0&268435455)>>>0};a.Color4f=function(g,d,k,m){void 0===m&&(m=1);return Float32Array.of(g,d,k,m)};Object.defineProperty(a,"TRANSPARENT",{get:function(){return a.Color4f(0,0,0,0)}});Object.defineProperty(a,"BLACK",{get:function(){return a.Color4f(0,0,0,1)}});Object.defineProperty(a,"WHITE",{get:function(){return a.Color4f(1,
1,1,1)}});Object.defineProperty(a,"RED",{get:function(){return a.Color4f(1,0,0,1)}});Object.defineProperty(a,"GREEN",{get:function(){return a.Color4f(0,1,0,1)}});Object.defineProperty(a,"BLUE",{get:function(){return a.Color4f(0,0,1,1)}});Object.defineProperty(a,"YELLOW",{get:function(){return a.Color4f(1,1,0,1)}});Object.defineProperty(a,"CYAN",{get:function(){return a.Color4f(0,1,1,1)}});Object.defineProperty(a,"MAGENTA",{get:function(){return a.Color4f(1,0,1,1)}});a.getColorComponents=function(g){return[Math.floor(255*
g[0]),Math.floor(255*g[1]),Math.floor(255*g[2]),g[3]]};a.parseColorString=function(g,d){g=g.toLowerCase();if(g.startsWith("#")){d=255;switch(g.length){case 9:d=parseInt(g.slice(7,9),16);case 7:var k=parseInt(g.slice(1,3),16);var m=parseInt(g.slice(3,5),16);var r=parseInt(g.slice(5,7),16);break;case 5:d=17*parseInt(g.slice(4,5),16);case 4:k=17*parseInt(g.slice(1,2),16),m=17*parseInt(g.slice(2,3),16),r=17*parseInt(g.slice(3,4),16)}return a.Color(k,m,r,d/255)}return g.startsWith("rgba")?(g=g.slice(5,
-1),g=g.split(","),a.Color(+g[0],+g[1],+g[2],e(g[3]))):g.startsWith("rgb")?(g=g.slice(4,-1),g=g.split(","),a.Color(+g[0],+g[1],+g[2],e(g[3]))):g.startsWith("gray(")||g.startsWith("hsl")||!d||(g=d[g],void 0===g)?a.BLACK:g};a.multiplyByAlpha=function(g,d){g=g.slice();g[3]=Math.max(0,Math.min(g[3]*d,1));return g};a.Malloc=function(g,d){var k=a._malloc(d*g.BYTES_PER_ELEMENT);return{_ck:!0,length:d,byteOffset:k,he:null,subarray:function(m,r){m=this.toTypedArray().subarray(m,r);m._ck=!0;return m},toTypedArray:function(){if(this.he&&
this.he.length)return this.he;this.he=new g(a.HEAPU8.buffer,k,d);this.he._ck=!0;return this.he}}};a.Free=function(g){a._free(g.byteOffset);g.byteOffset=K;g.toTypedArray=null;g.he=null};var P=K,aa,ma=K,Y,ea=K,Fa,ba,V=K,Ub,Ba=K,Vb,vb=K,Wb,wb=K,ab,Na=K,Xb,ub=K,Yb,Zb=K,Wc=Float32Array.of(0,0,1),K=0;a.te=function(g){return g.naturalWidth||g.videoWidth||g.displayWidth||g.width};a.se=function(g){return g.naturalHeight||g.videoHeight||g.displayHeight||g.height};a.onRuntimeInitialized=function(){function g(d,
k,m,r,u,x,B){x||(x=4*r.width,r.colorType===a.ColorType.RGBA_F16?x*=2:r.colorType===a.ColorType.RGBA_F32&&(x*=4));var F=x*r.height;var E=u?u.byteOffset:a._malloc(F);if(B?!d._readPixels(r,E,x,k,m,B):!d._readPixels(r,E,x,k,m))return u||a._free(E),null;if(u)return u.toTypedArray();switch(r.colorType){case a.ColorType.RGBA_8888:case a.ColorType.RGBA_F16:d=(new Uint8Array(a.HEAPU8.buffer,E,F)).slice();break;case a.ColorType.RGBA_F32:d=(new Float32Array(a.HEAPU8.buffer,E,F)).slice();break;default:return null}a._free(E);
return d}Fa=a.Malloc(Float32Array,4);ea=Fa.byteOffset;Y=a.Malloc(Float32Array,16);ma=Y.byteOffset;aa=a.Malloc(Float32Array,9);P=aa.byteOffset;Xb=a.Malloc(Float32Array,12);ub=Xb.byteOffset;Yb=a.Malloc(Float32Array,12);Zb=Yb.byteOffset;ba=a.Malloc(Float32Array,4);V=ba.byteOffset;Ub=a.Malloc(Float32Array,4);Ba=Ub.byteOffset;Vb=a.Malloc(Float32Array,3);vb=Vb.byteOffset;Wb=a.Malloc(Float32Array,3);wb=Wb.byteOffset;ab=a.Malloc(Int32Array,4);Na=ab.byteOffset;a.ColorSpace.SRGB=a.ColorSpace._MakeSRGB();a.ColorSpace.DISPLAY_P3=
a.ColorSpace._MakeDisplayP3();a.ColorSpace.ADOBE_RGB=a.ColorSpace._MakeAdobeRGB();a.GlyphRunFlags={IsWhiteSpace:a._GlyphRunFlags_isWhiteSpace};a.Path.MakeFromCmds=function(d){var k=l(d,"HEAPF32"),m=a.Path._MakeFromCmds(k,d.length);h(k,d);return m};a.Path.MakeFromVerbsPointsWeights=function(d,k,m){var r=l(d,"HEAPU8"),u=l(k,"HEAPF32"),x=l(m,"HEAPF32"),B=a.Path._MakeFromVerbsPointsWeights(r,d.length,u,k.length/2,x,m&&m.length||0);h(r,d);h(u,k);h(x,m);return B};a.PathBuilder.prototype.addArc=function(d,
k,m){d=I(d);this._addArc(d,k,m);return this};a.PathBuilder.prototype.addCircle=function(d,k,m,r){this._addCircle(d,k,m,!!r);return this};a.PathBuilder.prototype.addOval=function(d,k,m){void 0===m&&(m=1);d=I(d);this._addOval(d,!!k,m);return this};a.PathBuilder.prototype.addPath=function(){var d=Array.prototype.slice.call(arguments),k=d[0],m=!1;"boolean"===typeof d[d.length-1]&&(m=d.pop());if(1===d.length)this._addPath(k,1,0,0,0,1,0,0,0,1,m);else if(2===d.length)d=d[1],this._addPath(k,d[0],d[1],d[2],
d[3],d[4],d[5],d[6]||0,d[7]||0,d[8]||1,m);else if(7===d.length||10===d.length)this._addPath(k,d[1],d[2],d[3],d[4],d[5],d[6],d[7]||0,d[8]||0,d[9]||1,m);else return null;return this};a.PathBuilder.prototype.addPolygon=function(d,k){var m=l(d,"HEAPF32");this._addPolygon(m,d.length/2,k);h(m,d);return this};a.PathBuilder.prototype.addRect=function(d,k){d=I(d);this._addRect(d,!!k);return this};a.PathBuilder.prototype.addRRect=function(d,k){d=Q(d);this._addRRect(d,!!k);return this};a.PathBuilder.prototype.addVerbsPointsWeights=
function(d,k,m){var r=l(d,"HEAPU8"),u=l(k,"HEAPF32"),x=l(m,"HEAPF32");this._addVerbsPointsWeights(r,d.length,u,k.length/2,x,m&&m.length||0);h(r,d);h(u,k);h(x,m);return this};a.PathBuilder.prototype.arc=function(d,k,m,r,u,x){d=a.LTRBRect(d-m,k-m,d+m,k+m);u=(u-r)/Math.PI*180-360*!!x;r=(new a.PathBuilder).addArc(d,r/Math.PI*180,u).detachAndDelete();this.addPath(r,!0);r.delete();return this};a.PathBuilder.prototype.arcToOval=function(d,k,m,r){d=I(d);this._arcToOval(d,k,m,r);return this};a.PathBuilder.prototype.arcToRotated=
function(d,k,m,r,u,x,B){this._arcToRotated(d,k,m,!!r,!!u,x,B);return this};a.PathBuilder.prototype.arcToTangent=function(d,k,m,r,u){this._arcToTangent(d,k,m,r,u);return this};a.PathBuilder.prototype.close=function(){this._close();return this};a.PathBuilder.prototype.conicTo=function(d,k,m,r,u){this._conicTo(d,k,m,r,u);return this};a.Path.prototype.computeTightBounds=function(d){this._computeTightBounds(V);var k=ba.toTypedArray();return d?(d.set(k),d):k.slice()};a.PathBuilder.prototype.cubicTo=function(d,
k,m,r,u,x){this._cubicTo(d,k,m,r,u,x);return this};a.PathBuilder.prototype.detachAndDelete=function(){var d=this.detach();this.delete();return d};a.Path.prototype.getBounds=function(d){this._getBounds(V);var k=ba.toTypedArray();return d?(d.set(k),d):k.slice()};a.PathBuilder.prototype.getBounds=function(d){this._getBounds(V);var k=ba.toTypedArray();return d?(d.set(k),d):k.slice()};a.PathBuilder.prototype.lineTo=function(d,k){this._lineTo(d,k);return this};a.PathBuilder.prototype.moveTo=function(d,
k){this._moveTo(d,k);return this};a.PathBuilder.prototype.offset=function(d,k){this._transform(1,0,d,0,1,k,0,0,1);return this};a.PathBuilder.prototype.quadTo=function(d,k,m,r){this._quadTo(d,k,m,r);return this};a.PathBuilder.prototype.rArcTo=function(d,k,m,r,u,x,B){this._rArcTo(d,k,m,r,u,x,B);return this};a.PathBuilder.prototype.rConicTo=function(d,k,m,r,u){this._rConicTo(d,k,m,r,u);return this};a.PathBuilder.prototype.rCubicTo=function(d,k,m,r,u,x){this._rCubicTo(d,k,m,r,u,x);return this};a.PathBuilder.prototype.rLineTo=
function(d,k){this._rLineTo(d,k);return this};a.PathBuilder.prototype.rMoveTo=function(d,k){this._rMoveTo(d,k);return this};a.PathBuilder.prototype.rQuadTo=function(d,k,m,r){this._rQuadTo(d,k,m,r);return this};a.PathBuilder.prototype.setFillType=function(d){this._setFillType(d);return this};a.Path.prototype.makeStroked=function(d){d=d||{};d.width=d.width||1;d.miter_limit=d.miter_limit||4;d.cap=d.cap||a.StrokeCap.Butt;d.join=d.join||a.StrokeJoin.Miter;d.precision=d.precision||1;return this._makeStroked(d)};
a.PathBuilder.prototype.transform=function(){if(1===arguments.length){var d=arguments[0];this._transform(d[0],d[1],d[2],d[3],d[4],d[5],d[6]||0,d[7]||0,d[8]||1)}else if(6===arguments.length||9===arguments.length)d=arguments,this._transform(d[0],d[1],d[2],d[3],d[4],d[5],d[6]||0,d[7]||0,d[8]||1);else throw"transform expected to take 1 or 9 arguments. Got "+arguments.length;return this};a.Path.prototype.makeTrimmed=function(d,k,m){return this._makeTrimmed(d,k,!!m)};a.Image.prototype.encodeToBytes=function(d,
k){var m=a.ue();d=d||a.ImageFormat.PNG;k=k||100;return m?this._encodeToBytes(d,k,m):this._encodeToBytes(d,k)};a.Image.prototype.makeShaderCubic=function(d,k,m,r,u){u=t(u);return this._makeShaderCubic(d,k,m,r,u)};a.Image.prototype.makeShaderOptions=function(d,k,m,r,u){u=t(u);return this._makeShaderOptions(d,k,m,r,u)};a.Image.prototype.readPixels=function(d,k,m,r,u){var x=a.ue();return g(this,d,k,m,r,u,x)};a.Canvas.prototype.clear=function(d){a.Rd(this.Qd);d=y(d);this._clear(d)};a.Canvas.prototype.clipRRect=
function(d,k,m){a.Rd(this.Qd);d=Q(d);this._clipRRect(d,k,m)};a.Canvas.prototype.clipRect=function(d,k,m){a.Rd(this.Qd);d=I(d);this._clipRect(d,k,m)};a.Canvas.prototype.concat=function(d){a.Rd(this.Qd);d=v(d);this._concat(d)};a.Canvas.prototype.drawArc=function(d,k,m,r,u){a.Rd(this.Qd);d=I(d);this._drawArc(d,k,m,r,u)};a.Canvas.prototype.drawAtlas=function(d,k,m,r,u,x,B){if(d&&r&&k&&m&&k.length===m.length){a.Rd(this.Qd);u||(u=a.BlendMode.SrcOver);var F=l(k,"HEAPF32"),E=l(m,"HEAPF32"),T=m.length/4,U=
l(c(x),"HEAPU32");if(B&&"B"in B&&"C"in B)this._drawAtlasCubic(d,E,F,U,T,u,B.B,B.C,r);else{let n=a.FilterMode.Linear,w=a.MipmapMode.None;B&&(n=B.filter,"mipmap"in B&&(w=B.mipmap));this._drawAtlasOptions(d,E,F,U,T,u,n,w,r)}h(F,k);h(E,m);h(U,x)}};a.Canvas.prototype.drawCircle=function(d,k,m,r){a.Rd(this.Qd);this._drawCircle(d,k,m,r)};a.Canvas.prototype.drawColor=function(d,k){a.Rd(this.Qd);d=y(d);void 0!==k?this._drawColor(d,k):this._drawColor(d)};a.Canvas.prototype.drawColorInt=function(d,k){a.Rd(this.Qd);
this._drawColorInt(d,k||a.BlendMode.SrcOver)};a.Canvas.prototype.drawColorComponents=function(d,k,m,r,u){a.Rd(this.Qd);d=C(d,k,m,r);void 0!==u?this._drawColor(d,u):this._drawColor(d)};a.Canvas.prototype.drawDRRect=function(d,k,m){a.Rd(this.Qd);d=Q(d,ub);k=Q(k,Zb);this._drawDRRect(d,k,m)};a.Canvas.prototype.drawImage=function(d,k,m,r){a.Rd(this.Qd);this._drawImage(d,k,m,r||null)};a.Canvas.prototype.drawImageCubic=function(d,k,m,r,u,x){a.Rd(this.Qd);this._drawImageCubic(d,k,m,r,u,x||null)};a.Canvas.prototype.drawImageOptions=
function(d,k,m,r,u,x){a.Rd(this.Qd);this._drawImageOptions(d,k,m,r,u,x||null)};a.Canvas.prototype.drawImageNine=function(d,k,m,r,u){a.Rd(this.Qd);k=l(k,"HEAP32",Na);m=I(m);this._drawImageNine(d,k,m,r,u||null)};a.Canvas.prototype.drawImageRect=function(d,k,m,r,u){a.Rd(this.Qd);I(k,V);I(m,Ba);this._drawImageRect(d,V,Ba,r,!!u)};a.Canvas.prototype.drawImageRectCubic=function(d,k,m,r,u,x){a.Rd(this.Qd);I(k,V);I(m,Ba);this._drawImageRectCubic(d,V,Ba,r,u,x||null)};a.Canvas.prototype.drawImageRectOptions=
function(d,k,m,r,u,x){a.Rd(this.Qd);I(k,V);I(m,Ba);this._drawImageRectOptions(d,V,Ba,r,u,x||null)};a.Canvas.prototype.drawLine=function(d,k,m,r,u){a.Rd(this.Qd);this._drawLine(d,k,m,r,u)};a.Canvas.prototype.drawOval=function(d,k){a.Rd(this.Qd);d=I(d);this._drawOval(d,k)};a.Canvas.prototype.drawPaint=function(d){a.Rd(this.Qd);this._drawPaint(d)};a.Canvas.prototype.drawParagraph=function(d,k,m){a.Rd(this.Qd);this._drawParagraph(d,k,m)};a.Canvas.prototype.drawPatch=function(d,k,m,r,u){if(24>d.length)throw"Need 12 cubic points";
if(k&&4>k.length)throw"Need 4 colors";if(m&&8>m.length)throw"Need 4 shader coordinates";a.Rd(this.Qd);const x=l(d,"HEAPF32"),B=k?l(c(k),"HEAPU32"):K,F=m?l(m,"HEAPF32"):K;r||(r=a.BlendMode.Modulate);this._drawPatch(x,B,F,r,u);h(F,m);h(B,k);h(x,d)};a.Canvas.prototype.drawPath=function(d,k){a.Rd(this.Qd);this._drawPath(d,k)};a.Canvas.prototype.drawPicture=function(d){a.Rd(this.Qd);this._drawPicture(d)};a.Canvas.prototype.drawPoints=function(d,k,m){a.Rd(this.Qd);var r=l(k,"HEAPF32");this._drawPoints(d,
r,k.length/2,m);h(r,k)};a.Canvas.prototype.drawRRect=function(d,k){a.Rd(this.Qd);d=Q(d);this._drawRRect(d,k)};a.Canvas.prototype.drawRect=function(d,k){a.Rd(this.Qd);d=I(d);this._drawRect(d,k)};a.Canvas.prototype.drawRect4f=function(d,k,m,r,u){a.Rd(this.Qd);this._drawRect4f(d,k,m,r,u)};a.Canvas.prototype.drawShadow=function(d,k,m,r,u,x,B){a.Rd(this.Qd);var F=l(u,"HEAPF32"),E=l(x,"HEAPF32");k=l(k,"HEAPF32",vb);m=l(m,"HEAPF32",wb);this._drawShadow(d,k,m,r,F,E,B);h(F,u);h(E,x)};a.getShadowLocalBounds=
function(d,k,m,r,u,x,B){d=t(d);m=l(m,"HEAPF32",vb);r=l(r,"HEAPF32",wb);if(!this._getShadowLocalBounds(d,k,m,r,u,x,V))return null;k=ba.toTypedArray();return B?(B.set(k),B):k.slice()};a.Canvas.prototype.drawTextBlob=function(d,k,m,r){a.Rd(this.Qd);this._drawTextBlob(d,k,m,r)};a.Canvas.prototype.drawVertices=function(d,k,m){a.Rd(this.Qd);this._drawVertices(d,k,m)};a.Canvas.prototype.getDeviceClipBounds=function(d){this._getDeviceClipBounds(Na);var k=ab.toTypedArray();d?d.set(k):d=k.slice();return d};
a.Canvas.prototype.quickReject=function(d){d=I(d);return this._quickReject(d)};a.Canvas.prototype.getLocalToDevice=function(){this._getLocalToDevice(ma);for(var d=ma,k=Array(16),m=0;16>m;m++)k[m]=a.HEAPF32[d/4+m];return k};a.Canvas.prototype.getTotalMatrix=function(){this._getTotalMatrix(P);for(var d=Array(9),k=0;9>k;k++)d[k]=a.HEAPF32[P/4+k];return d};a.Canvas.prototype.makeSurface=function(d){d=this._makeSurface(d);d.Qd=this.Qd;return d};a.Canvas.prototype.readPixels=function(d,k,m,r,u){a.Rd(this.Qd);
return g(this,d,k,m,r,u)};a.Canvas.prototype.saveLayer=function(d,k,m,r,u){k=I(k);return this._saveLayer(d||null,k,m||null,r||0,u||a.TileMode.Clamp)};a.Canvas.prototype.writePixels=function(d,k,m,r,u,x,B,F){if(d.byteLength%(k*m))throw"pixels length must be a multiple of the srcWidth * srcHeight";a.Rd(this.Qd);var E=d.byteLength/(k*m);x=x||a.AlphaType.Unpremul;B=B||a.ColorType.RGBA_8888;F=F||a.ColorSpace.SRGB;var T=E*k;E=l(d,"HEAPU8");k=this._writePixels({width:k,height:m,colorType:B,alphaType:x,colorSpace:F},
E,T,r,u);h(E,d);return k};a.ColorFilter.MakeBlend=function(d,k,m){d=y(d);m=m||a.ColorSpace.SRGB;return a.ColorFilter._MakeBlend(d,k,m)};a.ColorFilter.MakeMatrix=function(d){if(!d||20!==d.length)throw"invalid color matrix";var k=l(d,"HEAPF32"),m=a.ColorFilter._makeMatrix(k);h(k,d);return m};a.ContourMeasure.prototype.getPosTan=function(d,k){this._getPosTan(d,V);d=ba.toTypedArray();return k?(k.set(d),k):d.slice()};a.ImageFilter.prototype.getOutputBounds=function(d,k,m){d=I(d,V);k=t(k);this._getOutputBounds(d,
k,Na);k=ab.toTypedArray();return m?(m.set(k),m):k.slice()};a.ImageFilter.MakeDropShadow=function(d,k,m,r,u,x){u=y(u,ea);return a.ImageFilter._MakeDropShadow(d,k,m,r,u,x)};a.ImageFilter.MakeDropShadowOnly=function(d,k,m,r,u,x){u=y(u,ea);return a.ImageFilter._MakeDropShadowOnly(d,k,m,r,u,x)};a.ImageFilter.MakeImage=function(d,k,m,r){m=I(m,V);r=I(r,Ba);if("B"in k&&"C"in k)return a.ImageFilter._MakeImageCubic(d,k.B,k.C,m,r);const u=k.filter;let x=a.MipmapMode.None;"mipmap"in k&&(x=k.mipmap);return a.ImageFilter._MakeImageOptions(d,
u,x,m,r)};a.ImageFilter.MakeMatrixTransform=function(d,k,m){d=t(d);if("B"in k&&"C"in k)return a.ImageFilter._MakeMatrixTransformCubic(d,k.B,k.C,m);const r=k.filter;let u=a.MipmapMode.None;"mipmap"in k&&(u=k.mipmap);return a.ImageFilter._MakeMatrixTransformOptions(d,r,u,m)};a.Paint.prototype.getColor=function(){this._getColor(ea);return H(ea)};a.Paint.prototype.setColor=function(d,k){k=k||null;d=y(d);this._setColor(d,k)};a.Paint.prototype.setColorComponents=function(d,k,m,r,u){u=u||null;d=C(d,k,m,
r);this._setColor(d,u)};a.Path.prototype.getPoint=function(d,k){this._getPoint(d,V);d=ba.toTypedArray();return k?(k[0]=d[0],k[1]=d[1],k):d.slice(0,2)};a.Picture.prototype.makeShader=function(d,k,m,r,u){r=t(r);u=I(u);return this._makeShader(d,k,m,r,u)};a.Picture.prototype.cullRect=function(d){this._cullRect(V);var k=ba.toTypedArray();return d?(d.set(k),d):k.slice()};a.PictureRecorder.prototype.beginRecording=function(d,k){d=I(d);return this._beginRecording(d,!!k)};a.Surface.prototype.getCanvas=function(){var d=
this._getCanvas();d.Qd=this.Qd;return d};a.Surface.prototype.makeImageSnapshot=function(d){a.Rd(this.Qd);d=l(d,"HEAP32",Na);return this._makeImageSnapshot(d)};a.Surface.prototype.makeSurface=function(d){a.Rd(this.Qd);d=this._makeSurface(d);d.Qd=this.Qd;return d};a.Surface.prototype.Se=function(d,k){this.ke||(this.ke=this.getCanvas());return requestAnimationFrame(function(){a.Rd(this.Qd);d(this.ke);this.flush(k)}.bind(this))};a.Surface.prototype.requestAnimationFrame||(a.Surface.prototype.requestAnimationFrame=
a.Surface.prototype.Se);a.Surface.prototype.Pe=function(d,k){this.ke||(this.ke=this.getCanvas());requestAnimationFrame(function(){a.Rd(this.Qd);d(this.ke);this.flush(k);this.dispose()}.bind(this))};a.Surface.prototype.drawOnce||(a.Surface.prototype.drawOnce=a.Surface.prototype.Pe);a.PathEffect.MakeDash=function(d,k){k||=0;if(!d.length||1===d.length%2)throw"Intervals array must have even length";var m=l(d,"HEAPF32");k=a.PathEffect._MakeDash(m,d.length,k);h(m,d);return k};a.PathEffect.MakeLine2D=function(d,
k){k=t(k);return a.PathEffect._MakeLine2D(d,k)};a.PathEffect.MakePath2D=function(d,k){d=t(d);return a.PathEffect._MakePath2D(d,k)};a.Shader.MakeColor=function(d,k){k=k||null;d=y(d);return a.Shader._MakeColor(d,k)};a.Shader.Blend=a.Shader.MakeBlend;a.Shader.Color=a.Shader.MakeColor;a.Shader.MakeLinearGradient=function(d,k,m,r,u,x,B,F){F=F||null;var E=p(m),T=l(r,"HEAPF32");B=B||0;x=t(x);var U=ba.toTypedArray();U.set(d);U.set(k,2);d=a.Shader._MakeLinearGradient(V,E.Zd,E.colorType,T,E.count,u,B,x,F);
h(E.Zd,m);r&&h(T,r);return d};a.Shader.MakeRadialGradient=function(d,k,m,r,u,x,B,F){F=F||null;var E=p(m),T=l(r,"HEAPF32");B=B||0;x=t(x);d=a.Shader._MakeRadialGradient(d[0],d[1],k,E.Zd,E.colorType,T,E.count,u,B,x,F);h(E.Zd,m);r&&h(T,r);return d};a.Shader.MakeSweepGradient=function(d,k,m,r,u,x,B,F,E,T){T=T||null;var U=p(m),n=l(r,"HEAPF32");B=B||0;F=F||0;E=E||360;x=t(x);d=a.Shader._MakeSweepGradient(d,k,U.Zd,U.colorType,n,U.count,u,F,E,B,x,T);h(U.Zd,m);r&&h(n,r);return d};a.Shader.MakeTwoPointConicalGradient=
function(d,k,m,r,u,x,B,F,E,T){T=T||null;var U=p(u),n=l(x,"HEAPF32");E=E||0;F=t(F);var w=ba.toTypedArray();w.set(d);w.set(m,2);d=a.Shader._MakeTwoPointConicalGradient(V,k,r,U.Zd,U.colorType,n,U.count,B,E,F,T);h(U.Zd,u);x&&h(n,x);return d};a.Vertices.prototype.bounds=function(d){this._bounds(V);var k=ba.toTypedArray();return d?(d.set(k),d):k.slice()};a.Ud&&a.Ud.forEach(function(d){d()})};a.computeTonalColors=function(g){var d=l(g.ambient,"HEAPF32"),k=l(g.spot,"HEAPF32");this._computeTonalColors(d,k);
var m={ambient:H(d),spot:H(k)};h(d,g.ambient);h(k,g.spot);return m};a.LTRBRect=function(g,d,k,m){return Float32Array.of(g,d,k,m)};a.XYWHRect=function(g,d,k,m){return Float32Array.of(g,d,g+k,d+m)};a.LTRBiRect=function(g,d,k,m){return Int32Array.of(g,d,k,m)};a.XYWHiRect=function(g,d,k,m){return Int32Array.of(g,d,g+k,d+m)};a.RRectXY=function(g,d,k){return Float32Array.of(g[0],g[1],g[2],g[3],d,k,d,k,d,k,d,k)};a.MakeAnimatedImageFromEncoded=function(g){g=new Uint8Array(g);var d=a._malloc(g.byteLength);
a.HEAPU8.set(g,d);return(g=a._decodeAnimatedImage(d,g.byteLength))?g:null};a.MakeImageFromEncoded=function(g){g=new Uint8Array(g);var d=a._malloc(g.byteLength);a.HEAPU8.set(g,d);return(g=a._decodeImage(d,g.byteLength))?g:null};var bb=null;a.MakeImageFromCanvasImageSource=function(g){var d=a.te(g),k=a.se(g);bb||=document.createElement("canvas");bb.width=d;bb.height=k;var m=bb.getContext("2d",{willReadFrequently:!0});m.drawImage(g,0,0);g=m.getImageData(0,0,d,k);return a.MakeImage({width:d,height:k,
alphaType:a.AlphaType.Unpremul,colorType:a.ColorType.RGBA_8888,colorSpace:a.ColorSpace.SRGB},g.data,4*d)};a.MakeImage=function(g,d,k){var m=a._malloc(d.length);a.HEAPU8.set(d,m);return a._MakeImage(g,m,d.length,k)};a.MakeVertices=function(g,d,k,m,r,u){var x=r&&r.length||0,B=0;k&&k.length&&(B|=1);m&&m.length&&(B|=2);void 0===u||u||(B|=4);g=new a._VerticesBuilder(g,d.length/2,x,B);l(d,"HEAPF32",g.positions());g.texCoords()&&l(k,"HEAPF32",g.texCoords());g.colors()&&l(c(m),"HEAPU32",g.colors());g.indices()&&
l(r,"HEAPU16",g.indices());return g.detach()};(function(g){g.Ud=g.Ud||[];g.Ud.push(function(){function d(n){n&&(n.dir=0===n.dir?g.TextDirection.RTL:g.TextDirection.LTR);return n}function k(n){if(!n||!n.length)return[];for(var w=[],N=0;N<n.length;N+=5){var X=g.LTRBRect(n[N],n[N+1],n[N+2],n[N+3]),xa=g.TextDirection.LTR;0===n[N+4]&&(xa=g.TextDirection.RTL);w.push({rect:X,dir:xa})}g._free(n.byteOffset);return w}function m(n){n=n||{};void 0===n.weight&&(n.weight=g.FontWeight.Normal);n.width=n.width||g.FontWidth.Normal;
n.slant=n.slant||g.FontSlant.Upright;return n}function r(n){if(!n||!n.length)return K;for(var w=[],N=0;N<n.length;N++){var X=u(n[N]);w.push(X)}return l(w,"HEAPU32")}function u(n){if(F[n])return F[n];var w=qa(n)+1,N=g._malloc(w);ra(n,N,w);return F[n]=N}function x(n){n._colorPtr=y(n.color);n._foregroundColorPtr=K;n._backgroundColorPtr=K;n._decorationColorPtr=K;n.foregroundColor&&(n._foregroundColorPtr=y(n.foregroundColor,E));n.backgroundColor&&(n._backgroundColorPtr=y(n.backgroundColor,T));n.decorationColor&&
(n._decorationColorPtr=y(n.decorationColor,U));Array.isArray(n.fontFamilies)&&n.fontFamilies.length?(n._fontFamiliesPtr=r(n.fontFamilies),n._fontFamiliesLen=n.fontFamilies.length):(n._fontFamiliesPtr=K,n._fontFamiliesLen=0);if(n.locale){var w=n.locale;n._localePtr=u(w);n._localeLen=qa(w)}else n._localePtr=K,n._localeLen=0;if(Array.isArray(n.shadows)&&n.shadows.length){w=n.shadows;var N=w.map(function(na){return na.color||g.BLACK}),X=w.map(function(na){return na.blurRadius||0});n._shadowLen=w.length;
for(var xa=g._malloc(8*w.length),xb=xa/4,yb=0;yb<w.length;yb++){var $b=w[yb].offset||[0,0];g.HEAPF32[xb]=$b[0];g.HEAPF32[xb+1]=$b[1];xb+=2}n._shadowColorsPtr=p(N).Zd;n._shadowOffsetsPtr=xa;n._shadowBlurRadiiPtr=l(X,"HEAPF32")}else n._shadowLen=0,n._shadowColorsPtr=K,n._shadowOffsetsPtr=K,n._shadowBlurRadiiPtr=K;Array.isArray(n.fontFeatures)&&n.fontFeatures.length?(w=n.fontFeatures,N=w.map(function(na){return na.name}),X=w.map(function(na){return na.value}),n._fontFeatureLen=w.length,n._fontFeatureNamesPtr=
r(N),n._fontFeatureValuesPtr=l(X,"HEAPU32")):(n._fontFeatureLen=0,n._fontFeatureNamesPtr=K,n._fontFeatureValuesPtr=K);Array.isArray(n.fontVariations)&&n.fontVariations.length?(w=n.fontVariations,N=w.map(function(na){return na.axis}),X=w.map(function(na){return na.value}),n._fontVariationLen=w.length,n._fontVariationAxesPtr=r(N),n._fontVariationValuesPtr=l(X,"HEAPF32")):(n._fontVariationLen=0,n._fontVariationAxesPtr=K,n._fontVariationValuesPtr=K)}function B(n){g._free(n._fontFamiliesPtr);g._free(n._shadowColorsPtr);
g._free(n._shadowOffsetsPtr);g._free(n._shadowBlurRadiiPtr);g._free(n._fontFeatureNamesPtr);g._free(n._fontFeatureValuesPtr);g._free(n._fontVariationAxesPtr);g._free(n._fontVariationValuesPtr)}g.Paragraph.prototype.getRectsForRange=function(n,w,N,X){n=this._getRectsForRange(n,w,N,X);return k(n)};g.Paragraph.prototype.getRectsForPlaceholders=function(){var n=this._getRectsForPlaceholders();return k(n)};g.Paragraph.prototype.getGlyphInfoAt=function(n){return d(this._getGlyphInfoAt(n))};g.Paragraph.prototype.getClosestGlyphInfoAtCoordinate=
function(n,w){return d(this._getClosestGlyphInfoAtCoordinate(n,w))};g.TypefaceFontProvider.prototype.registerFont=function(n,w){n=g.Typeface.MakeTypefaceFromData(n);if(!n)return null;w=u(w);this._registerFont(n,w);n.delete()};g.ParagraphStyle=function(n){n.disableHinting=n.disableHinting||!1;if(n.ellipsis){var w=n.ellipsis;n._ellipsisPtr=u(w);n._ellipsisLen=qa(w)}else n._ellipsisPtr=K,n._ellipsisLen=0;null==n.heightMultiplier&&(n.heightMultiplier=-1);n.maxLines=n.maxLines||0;n.replaceTabCharacters=
n.replaceTabCharacters||!1;w=(w=n.strutStyle)||{};w.strutEnabled=w.strutEnabled||!1;w.strutEnabled&&Array.isArray(w.fontFamilies)&&w.fontFamilies.length?(w._fontFamiliesPtr=r(w.fontFamilies),w._fontFamiliesLen=w.fontFamilies.length):(w._fontFamiliesPtr=K,w._fontFamiliesLen=0);w.fontStyle=m(w.fontStyle);null==w.fontSize&&(w.fontSize=-1);null==w.heightMultiplier&&(w.heightMultiplier=-1);w.halfLeading=w.halfLeading||!1;w.leading=w.leading||0;w.forceStrutHeight=w.forceStrutHeight||!1;n.strutStyle=w;n.textAlign=
n.textAlign||g.TextAlign.Start;n.textDirection=n.textDirection||g.TextDirection.LTR;n.textHeightBehavior=n.textHeightBehavior||g.TextHeightBehavior.All;n.textStyle=g.TextStyle(n.textStyle);n.applyRoundingHack=!1!==n.applyRoundingHack;return n};g.TextStyle=function(n){n.color||(n.color=g.BLACK);n.decoration=n.decoration||0;n.decorationThickness=n.decorationThickness||0;n.decorationStyle=n.decorationStyle||g.DecorationStyle.Solid;n.textBaseline=n.textBaseline||g.TextBaseline.Alphabetic;null==n.fontSize&&
(n.fontSize=-1);n.letterSpacing=n.letterSpacing||0;n.wordSpacing=n.wordSpacing||0;null==n.heightMultiplier&&(n.heightMultiplier=-1);n.halfLeading=n.halfLeading||!1;n.fontStyle=m(n.fontStyle);return n};var F={},E=g._malloc(16),T=g._malloc(16),U=g._malloc(16);g.ParagraphBuilder.Make=function(n,w){x(n.textStyle);w=g.ParagraphBuilder._Make(n,w);B(n.textStyle);return w};g.ParagraphBuilder.MakeFromFontProvider=function(n,w){x(n.textStyle);w=g.ParagraphBuilder._MakeFromFontProvider(n,w);B(n.textStyle);return w};
g.ParagraphBuilder.MakeFromFontCollection=function(n,w){x(n.textStyle);w=g.ParagraphBuilder._MakeFromFontCollection(n,w);B(n.textStyle);return w};g.ParagraphBuilder.ShapeText=function(n,w,N){let X=0;for(const xa of w)X+=xa.length;if(X!==n.length)throw"Accumulated block lengths must equal text.length";return g.ParagraphBuilder._ShapeText(n,w,N)};g.ParagraphBuilder.prototype.pushStyle=function(n){x(n);this._pushStyle(n);B(n)};g.ParagraphBuilder.prototype.pushPaintStyle=function(n,w,N){x(n);this._pushPaintStyle(n,
w,N);B(n)};g.ParagraphBuilder.prototype.addPlaceholder=function(n,w,N,X,xa){N=N||g.PlaceholderAlignment.Baseline;X=X||g.TextBaseline.Alphabetic;this._addPlaceholder(n||0,w||0,N,X,xa||0)};g.ParagraphBuilder.prototype.setWordsUtf8=function(n){var w=l(n,"HEAPU32");this._setWordsUtf8(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setWordsUtf16=function(n){var w=l(n,"HEAPU32");this._setWordsUtf16(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setGraphemeBreaksUtf8=function(n){var w=l(n,
"HEAPU32");this._setGraphemeBreaksUtf8(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setGraphemeBreaksUtf16=function(n){var w=l(n,"HEAPU32");this._setGraphemeBreaksUtf16(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setLineBreaksUtf8=function(n){var w=l(n,"HEAPU32");this._setLineBreaksUtf8(w,n&&n.length||0);h(w,n)};g.ParagraphBuilder.prototype.setLineBreaksUtf16=function(n){var w=l(n,"HEAPU32");this._setLineBreaksUtf16(w,n&&n.length||0);h(w,n)}})})(q);a.Ud=a.Ud||[];a.Ud.push(function(){});
a.Ud=a.Ud||[];a.Ud.push(function(){a.Canvas.prototype.drawText=function(g,d,k,m,r){var u=qa(g),x=a._malloc(u+1);ra(g,x,u+1);this._drawSimpleText(x,u,d,k,r,m);a._free(x)};a.Canvas.prototype.drawGlyphs=function(g,d,k,m,r,u){if(!(2*g.length<=d.length))throw"Not enough positions for the array of gyphs";a.Rd(this.Qd);const x=l(g,"HEAPU16"),B=l(d,"HEAPF32");this._drawGlyphs(g.length,x,B,k,m,r,u);h(B,d);h(x,g)};a.Font.prototype.getGlyphBounds=function(g,d,k){var m=l(g,"HEAPU16"),r=a._malloc(16*g.length);
this._getGlyphWidthBounds(m,g.length,K,r,d||null);d=new Float32Array(a.HEAPU8.buffer,r,4*g.length);h(m,g);if(k)return k.set(d),a._free(r),k;g=Float32Array.from(d);a._free(r);return g};a.Font.prototype.getGlyphIDs=function(g,d,k){d||(d=g.length);var m=qa(g)+1,r=a._malloc(m);ra(g,r,m);g=a._malloc(2*d);d=this._getGlyphIDs(r,m-1,d,g);a._free(r);if(0>d)return a._free(g),null;r=new Uint16Array(a.HEAPU8.buffer,g,d);if(k)return k.set(r),a._free(g),k;k=Uint16Array.from(r);a._free(g);return k};a.Font.prototype.getGlyphIntercepts=
function(g,d,k,m){var r=l(g,"HEAPU16"),u=l(d,"HEAPF32");return this._getGlyphIntercepts(r,g.length,!(g&&g._ck),u,d.length,!(d&&d._ck),k,m)};a.Font.prototype.getGlyphWidths=function(g,d,k){var m=l(g,"HEAPU16"),r=a._malloc(4*g.length);this._getGlyphWidthBounds(m,g.length,r,K,d||null);d=new Float32Array(a.HEAPU8.buffer,r,g.length);h(m,g);if(k)return k.set(d),a._free(r),k;g=Float32Array.from(d);a._free(r);return g};a.FontMgr.FromData=function(){if(!arguments.length)return null;var g=arguments;1===g.length&&
Array.isArray(g[0])&&(g=arguments[0]);if(!g.length)return null;for(var d=[],k=[],m=0;m<g.length;m++){var r=new Uint8Array(g[m]),u=l(r,"HEAPU8");d.push(u);k.push(r.byteLength)}d=l(d,"HEAPU32");k=l(k,"HEAPU32");g=a.FontMgr._fromData(d,k,g.length);a._free(d);a._free(k);return g};a.Typeface.MakeTypefaceFromData=function(g){g=new Uint8Array(g);var d=l(g,"HEAPU8");return(g=a.Typeface._MakeTypefaceFromData(d,g.byteLength))?g:null};a.Typeface.MakeFreeTypeFaceFromData=a.Typeface.MakeTypefaceFromData;a.Typeface.prototype.getGlyphIDs=
function(g,d,k){d||(d=g.length);var m=qa(g)+1,r=a._malloc(m);ra(g,r,m);g=a._malloc(2*d);d=this._getGlyphIDs(r,m-1,d,g);a._free(r);if(0>d)return a._free(g),null;r=new Uint16Array(a.HEAPU8.buffer,g,d);if(k)return k.set(r),a._free(g),k;k=Uint16Array.from(r);a._free(g);return k};a.TextBlob.MakeOnPath=function(g,d,k,m){if(g&&g.length&&d&&d.countPoints()){if(1===d.countPoints())return this.MakeFromText(g,k);m||=0;var r=k.getGlyphIDs(g);r=k.getGlyphWidths(r);var u=[];d=new a.ContourMeasureIter(d,!1,1);for(var x=
d.next(),B=new Float32Array(4),F=0;F<g.length&&x;F++){var E=r[F];m+=E/2;if(m>x.length()){x.delete();x=d.next();if(!x){g=g.substring(0,F);break}m=E/2}x.getPosTan(m,B);var T=B[2],U=B[3];u.push(T,U,B[0]-E/2*T,B[1]-E/2*U);m+=E/2}g=this.MakeFromRSXform(g,u,k);x&&x.delete();d.delete();return g}};a.TextBlob.MakeFromRSXform=function(g,d,k){var m=qa(g)+1,r=a._malloc(m);ra(g,r,m);g=l(d,"HEAPF32");k=a.TextBlob._MakeFromRSXform(r,m-1,g,k);a._free(r);return k?k:null};a.TextBlob.MakeFromRSXformGlyphs=function(g,
d,k){var m=l(g,"HEAPU16");d=l(d,"HEAPF32");k=a.TextBlob._MakeFromRSXformGlyphs(m,2*g.length,d,k);h(m,g);return k?k:null};a.TextBlob.MakeFromGlyphs=function(g,d){var k=l(g,"HEAPU16");d=a.TextBlob._MakeFromGlyphs(k,2*g.length,d);h(k,g);return d?d:null};a.TextBlob.MakeFromText=function(g,d){var k=qa(g)+1,m=a._malloc(k);ra(g,m,k);g=a.TextBlob._MakeFromText(m,k-1,d);a._free(m);return g?g:null};a.MallocGlyphIDs=function(g){return a.Malloc(Uint16Array,g)}});a.Ud=a.Ud||[];a.Ud.push(function(){a.MakePicture=
function(g){g=new Uint8Array(g);var d=a._malloc(g.byteLength);a.HEAPU8.set(g,d);return(g=a._MakePicture(d,g.byteLength))?g:null}});a.Ud=a.Ud||[];a.Ud.push(function(){a.RuntimeEffect.Make=function(g,d){return a.RuntimeEffect._Make(g,{onError:d||function(k){console.log("RuntimeEffect error",k)}})};a.RuntimeEffect.MakeForBlender=function(g,d){return a.RuntimeEffect._MakeForBlender(g,{onError:d||function(k){console.log("RuntimeEffect error",k)}})};a.RuntimeEffect.prototype.makeShader=function(g,d){var k=
!g._ck,m=l(g,"HEAPF32");d=t(d);return this._makeShader(m,4*g.length,k,d)};a.RuntimeEffect.prototype.makeShaderWithChildren=function(g,d,k){var m=!g._ck,r=l(g,"HEAPF32");k=t(k);for(var u=[],x=0;x<d.length;x++)u.push(d[x].Pd.Sd);d=l(u,"HEAPU32");return this._makeShaderWithChildren(r,4*g.length,m,d,u.length,k)};a.RuntimeEffect.prototype.makeBlender=function(g){var d=!g._ck,k=l(g,"HEAPF32");return this._makeBlender(k,4*g.length,d)}})})(q);var sa=Object.assign({},q),ta="",ua,va;
if(ha||ia)ia?ta=self.location.href:"undefined"!=typeof document&&document.currentScript&&(ta=document.currentScript.src),_scriptName&&(ta=_scriptName),ta.startsWith("blob:")?ta="":ta=ta.substr(0,ta.replace(/[?#].*/,"").lastIndexOf("/")+1),ia&&(va=a=>{var b=new XMLHttpRequest;b.open("GET",a,!1);b.responseType="arraybuffer";b.send(null);return new Uint8Array(b.response)}),ua=a=>fetch(a,{credentials:"same-origin"}).then(b=>b.ok?b.arrayBuffer():Promise.reject(Error(b.status+" : "+b.url)));
var wa=console.log.bind(console),ya=console.error.bind(console);Object.assign(q,sa);sa=null;var za,Aa=!1,Ca,A,Da,Ea,D,G,J,Ga;function Ha(){var a=za.buffer;q.HEAP8=Ca=new Int8Array(a);q.HEAP16=Da=new Int16Array(a);q.HEAPU8=A=new Uint8Array(a);q.HEAPU16=Ea=new Uint16Array(a);q.HEAP32=D=new Int32Array(a);q.HEAPU32=G=new Uint32Array(a);q.HEAPF32=J=new Float32Array(a);q.HEAPF64=Ga=new Float64Array(a)}var Ia=[],Ja=[],Ka=[],La=0,Ma=null,Oa=null;
function Pa(a){a="Aborted("+a+")";ya(a);Aa=!0;a=new WebAssembly.RuntimeError(a+". Build with -sASSERTIONS for more info.");da(a);throw a;}var Qa=a=>a.startsWith("data:application/octet-stream;base64,"),Ra;function Sa(a){return ua(a).then(b=>new Uint8Array(b),()=>{if(va)var b=va(a);else throw"both async and sync fetching of the wasm failed";return b})}function Ta(a,b,c){return Sa(a).then(e=>WebAssembly.instantiate(e,b)).then(c,e=>{ya(`failed to asynchronously prepare wasm: ${e}`);Pa(e)})}
function Ua(a,b){var c=Ra;return"function"!=typeof WebAssembly.instantiateStreaming||Qa(c)||"function"!=typeof fetch?Ta(c,a,b):fetch(c,{credentials:"same-origin"}).then(e=>WebAssembly.instantiateStreaming(e,a).then(b,function(f){ya(`wasm streaming compile failed: ${f}`);ya("falling back to ArrayBuffer instantiation");return Ta(c,a,b)}))}var Va=a=>{a.forEach(b=>b(q))};class Wa{constructor(a){this.Sd=a-24}}
var Xa=0,Ya=0,Za="undefined"!=typeof TextDecoder?new TextDecoder:void 0,$a=(a,b=0,c=NaN)=>{var e=b+c;for(c=b;a[c]&&!(c>=e);)++c;if(16<c-b&&a.buffer&&Za)return Za.decode(a.subarray(b,c));for(e="";b<c;){var f=a[b++];if(f&128){var h=a[b++]&63;if(192==(f&224))e+=String.fromCharCode((f&31)<<6|h);else{var l=a[b++]&63;f=224==(f&240)?(f&15)<<12|h<<6|l:(f&7)<<18|h<<12|l<<6|a[b++]&63;65536>f?e+=String.fromCharCode(f):(f-=65536,e+=String.fromCharCode(55296|f>>10,56320|f&1023))}}else e+=String.fromCharCode(f)}return e},
cb={},db=a=>{for(;a.length;){var b=a.pop();a.pop()(b)}};function eb(a){return this.fromWireType(G[a>>2])}
var fb={},gb={},hb={},ib,kb=(a,b,c)=>{function e(p){p=c(p);if(p.length!==a.length)throw new ib("Mismatched type converter count");for(var t=0;t<a.length;++t)jb(a[t],p[t])}a.forEach(p=>hb[p]=b);var f=Array(b.length),h=[],l=0;b.forEach((p,t)=>{gb.hasOwnProperty(p)?f[t]=gb[p]:(h.push(p),fb.hasOwnProperty(p)||(fb[p]=[]),fb[p].push(()=>{f[t]=gb[p];++l;l===h.length&&e(f)}))});0===h.length&&e(f)},lb,L=a=>{for(var b="";A[a];)b+=lb[A[a++]];return b},M;
function mb(a,b,c={}){var e=b.name;if(!a)throw new M(`type "${e}" must have a positive integer typeid pointer`);if(gb.hasOwnProperty(a)){if(c.df)return;throw new M(`Cannot register type '${e}' twice`);}gb[a]=b;delete hb[a];fb.hasOwnProperty(a)&&(b=fb[a],delete fb[a],b.forEach(f=>f()))}function jb(a,b,c={}){return mb(a,b,c)}
var nb=a=>{throw new M(a.Pd.Vd.Td.name+" instance already deleted");},ob=!1,pb=()=>{},qb=(a,b,c)=>{if(b===c)return a;if(void 0===c.Yd)return null;a=qb(a,b,c.Yd);return null===a?null:c.We(a)},rb={},sb={},tb=(a,b)=>{if(void 0===b)throw new M("ptr should not be undefined");for(;a.Yd;)b=a.pe(b),a=a.Yd;return sb[b]},Ab=(a,b)=>{if(!b.Vd||!b.Sd)throw new ib("makeClassHandle requires ptr and ptrType");if(!!b.$d!==!!b.Wd)throw new ib("Both smartPtrType and smartPtr must be specified");b.count={value:1};return zb(Object.create(a,
{Pd:{value:b,writable:!0}}))},zb=a=>{if("undefined"===typeof FinalizationRegistry)return zb=b=>b,a;ob=new FinalizationRegistry(b=>{b=b.Pd;--b.count.value;0===b.count.value&&(b.Wd?b.$d.ee(b.Wd):b.Vd.Td.ee(b.Sd))});zb=b=>{var c=b.Pd;c.Wd&&ob.register(b,{Pd:c},b);return b};pb=b=>{ob.unregister(b)};return zb(a)},Bb=[];function Cb(){}
var Db=(a,b)=>Object.defineProperty(b,"name",{value:a}),Eb=(a,b,c)=>{if(void 0===a[b].Xd){var e=a[b];a[b]=function(...f){if(!a[b].Xd.hasOwnProperty(f.length))throw new M(`Function '${c}' called with an invalid number of arguments (${f.length}) - expects one of (${a[b].Xd})!`);return a[b].Xd[f.length].apply(this,f)};a[b].Xd=[];a[b].Xd[e.fe]=e}},Fb=(a,b,c)=>{if(q.hasOwnProperty(a)){if(void 0===c||void 0!==q[a].Xd&&void 0!==q[a].Xd[c])throw new M(`Cannot register public name '${a}' twice`);Eb(q,a,a);
if(q[a].Xd.hasOwnProperty(c))throw new M(`Cannot register multiple overloads of a function with the same number of arguments (${c})!`);q[a].Xd[c]=b}else q[a]=b,q[a].fe=c},Gb=a=>{a=a.replace(/[^a-zA-Z0-9_]/g,"$");var b=a.charCodeAt(0);return 48<=b&&57>=b?`_${a}`:a};function Hb(a,b,c,e,f,h,l,p){this.name=a;this.constructor=b;this.je=c;this.ee=e;this.Yd=f;this.Ze=h;this.pe=l;this.We=p;this.gf=[]}
var Ib=(a,b,c)=>{for(;b!==c;){if(!b.pe)throw new M(`Expected null or instance of ${c.name}, got an instance of ${b.name}`);a=b.pe(a);b=b.Yd}return a};function Jb(a,b){if(null===b){if(this.De)throw new M(`null is not a valid ${this.name}`);return 0}if(!b.Pd)throw new M(`Cannot pass "${Kb(b)}" as a ${this.name}`);if(!b.Pd.Sd)throw new M(`Cannot pass deleted object as a pointer of type ${this.name}`);return Ib(b.Pd.Sd,b.Pd.Vd.Td,this.Td)}
function Lb(a,b){if(null===b){if(this.De)throw new M(`null is not a valid ${this.name}`);if(this.we){var c=this.Ee();null!==a&&a.push(this.ee,c);return c}return 0}if(!b||!b.Pd)throw new M(`Cannot pass "${Kb(b)}" as a ${this.name}`);if(!b.Pd.Sd)throw new M(`Cannot pass deleted object as a pointer of type ${this.name}`);if(!this.ve&&b.Pd.Vd.ve)throw new M(`Cannot convert argument of type ${b.Pd.$d?b.Pd.$d.name:b.Pd.Vd.name} to parameter type ${this.name}`);c=Ib(b.Pd.Sd,b.Pd.Vd.Td,this.Td);if(this.we){if(void 0===
b.Pd.Wd)throw new M("Passing raw pointer to smart pointer is illegal");switch(this.mf){case 0:if(b.Pd.$d===this)c=b.Pd.Wd;else throw new M(`Cannot convert argument of type ${b.Pd.$d?b.Pd.$d.name:b.Pd.Vd.name} to parameter type ${this.name}`);break;case 1:c=b.Pd.Wd;break;case 2:if(b.Pd.$d===this)c=b.Pd.Wd;else{var e=b.clone();c=this.hf(c,Mb(()=>e["delete"]()));null!==a&&a.push(this.ee,c)}break;default:throw new M("Unsupporting sharing policy");}}return c}
function Nb(a,b){if(null===b){if(this.De)throw new M(`null is not a valid ${this.name}`);return 0}if(!b.Pd)throw new M(`Cannot pass "${Kb(b)}" as a ${this.name}`);if(!b.Pd.Sd)throw new M(`Cannot pass deleted object as a pointer of type ${this.name}`);if(b.Pd.Vd.ve)throw new M(`Cannot convert argument of type ${b.Pd.Vd.name} to parameter type ${this.name}`);return Ib(b.Pd.Sd,b.Pd.Vd.Td,this.Td)}
function Ob(a,b,c,e,f,h,l,p,t,v,y){this.name=a;this.Td=b;this.De=c;this.ve=e;this.we=f;this.ff=h;this.mf=l;this.Le=p;this.Ee=t;this.hf=v;this.ee=y;f||void 0!==b.Yd?this.toWireType=Lb:(this.toWireType=e?Jb:Nb,this.be=null)}
var Pb=(a,b,c)=>{if(!q.hasOwnProperty(a))throw new ib("Replacing nonexistent public symbol");void 0!==q[a].Xd&&void 0!==c?q[a].Xd[c]=b:(q[a]=b,q[a].fe=c)},Qb,Rb=(a,b,c=[])=>{a.includes("j")?(a=a.replace(/p/g,"i"),b=(0,q["dynCall_"+a])(b,...c)):b=Qb.get(b)(...c);return b},Sb=(a,b)=>(...c)=>Rb(a,b,c),O=(a,b)=>{a=L(a);var c=a.includes("j")?Sb(a,b):Qb.get(b);if("function"!=typeof c)throw new M(`unknown function pointer with signature ${a}: ${b}`);return c},Tb,cc=a=>{a=ac(a);var b=L(a);bc(a);return b},
dc=(a,b)=>{function c(h){f[h]||gb[h]||(hb[h]?hb[h].forEach(c):(e.push(h),f[h]=!0))}var e=[],f={};b.forEach(c);throw new Tb(`${a}: `+e.map(cc).join([", "]));};function ec(a){for(var b=1;b<a.length;++b)if(null!==a[b]&&void 0===a[b].be)return!0;return!1}
function fc(a,b,c,e,f){var h=b.length;if(2>h)throw new M("argTypes array size mismatch! Must at least get return value and 'this' types!");var l=null!==b[1]&&null!==c,p=ec(b),t="void"!==b[0].name,v=h-2,y=Array(v),C=[],H=[];return Db(a,function(...I){H.length=0;C.length=l?2:1;C[0]=f;if(l){var Q=b[1].toWireType(H,this);C[1]=Q}for(var P=0;P<v;++P)y[P]=b[P+2].toWireType(H,I[P]),C.push(y[P]);I=e(...C);if(p)db(H);else for(P=l?1:2;P<b.length;P++){var aa=1===P?Q:y[P-2];null!==b[P].be&&b[P].be(aa)}Q=t?b[0].fromWireType(I):
void 0;return Q})}
var gc=(a,b)=>{for(var c=[],e=0;e<a;e++)c.push(G[b+4*e>>2]);return c},hc=a=>{a=a.trim();const b=a.indexOf("(");return-1!==b?a.substr(0,b):a},ic=[],jc=[],kc=a=>{9<a&&0===--jc[a+1]&&(jc[a]=void 0,ic.push(a))},lc=a=>{if(!a)throw new M("Cannot use deleted val. handle = "+a);return jc[a]},Mb=a=>{switch(a){case void 0:return 2;case null:return 4;case !0:return 6;case !1:return 8;default:const b=ic.pop()||jc.length;jc[b]=a;jc[b+1]=1;return b}},mc={name:"emscripten::val",fromWireType:a=>{var b=lc(a);kc(a);
return b},toWireType:(a,b)=>Mb(b),ae:8,readValueFromPointer:eb,be:null},nc=(a,b,c)=>{switch(b){case 1:return c?function(e){return this.fromWireType(Ca[e])}:function(e){return this.fromWireType(A[e])};case 2:return c?function(e){return this.fromWireType(Da[e>>1])}:function(e){return this.fromWireType(Ea[e>>1])};case 4:return c?function(e){return this.fromWireType(D[e>>2])}:function(e){return this.fromWireType(G[e>>2])};default:throw new TypeError(`invalid integer width (${b}): ${a}`);}},oc=(a,b)=>
{var c=gb[a];if(void 0===c)throw a=`${b} has unknown type ${cc(a)}`,new M(a);return c},Kb=a=>{if(null===a)return"null";var b=typeof a;return"object"===b||"array"===b||"function"===b?a.toString():""+a},pc=(a,b)=>{switch(b){case 4:return function(c){return this.fromWireType(J[c>>2])};case 8:return function(c){return this.fromWireType(Ga[c>>3])};default:throw new TypeError(`invalid float width (${b}): ${a}`);}},qc=(a,b,c)=>{switch(b){case 1:return c?e=>Ca[e]:e=>A[e];case 2:return c?e=>Da[e>>1]:e=>Ea[e>>
1];case 4:return c?e=>D[e>>2]:e=>G[e>>2];default:throw new TypeError(`invalid integer width (${b}): ${a}`);}},ra=(a,b,c)=>{var e=A;if(!(0<c))return 0;var f=b;c=b+c-1;for(var h=0;h<a.length;++h){var l=a.charCodeAt(h);if(55296<=l&&57343>=l){var p=a.charCodeAt(++h);l=65536+((l&1023)<<10)|p&1023}if(127>=l){if(b>=c)break;e[b++]=l}else{if(2047>=l){if(b+1>=c)break;e[b++]=192|l>>6}else{if(65535>=l){if(b+2>=c)break;e[b++]=224|l>>12}else{if(b+3>=c)break;e[b++]=240|l>>18;e[b++]=128|l>>12&63}e[b++]=128|l>>6&
63}e[b++]=128|l&63}}e[b]=0;return b-f},qa=a=>{for(var b=0,c=0;c<a.length;++c){var e=a.charCodeAt(c);127>=e?b++:2047>=e?b+=2:55296<=e&&57343>=e?(b+=4,++c):b+=3}return b},rc="undefined"!=typeof TextDecoder?new TextDecoder("utf-16le"):void 0,sc=(a,b)=>{var c=a>>1;for(var e=c+b/2;!(c>=e)&&Ea[c];)++c;c<<=1;if(32<c-a&&rc)return rc.decode(A.subarray(a,c));c="";for(e=0;!(e>=b/2);++e){var f=Da[a+2*e>>1];if(0==f)break;c+=String.fromCharCode(f)}return c},tc=(a,b,c)=>{c??=2147483647;if(2>c)return 0;c-=2;var e=
b;c=c<2*a.length?c/2:a.length;for(var f=0;f<c;++f)Da[b>>1]=a.charCodeAt(f),b+=2;Da[b>>1]=0;return b-e},uc=a=>2*a.length,vc=(a,b)=>{for(var c=0,e="";!(c>=b/4);){var f=D[a+4*c>>2];if(0==f)break;++c;65536<=f?(f-=65536,e+=String.fromCharCode(55296|f>>10,56320|f&1023)):e+=String.fromCharCode(f)}return e},wc=(a,b,c)=>{c??=2147483647;if(4>c)return 0;var e=b;c=e+c-4;for(var f=0;f<a.length;++f){var h=a.charCodeAt(f);if(55296<=h&&57343>=h){var l=a.charCodeAt(++f);h=65536+((h&1023)<<10)|l&1023}D[b>>2]=h;b+=
4;if(b+4>c)break}D[b>>2]=0;return b-e},xc=a=>{for(var b=0,c=0;c<a.length;++c){var e=a.charCodeAt(c);55296<=e&&57343>=e&&++c;b+=4}return b},yc=(a,b,c)=>{var e=[];a=a.toWireType(e,c);e.length&&(G[b>>2]=Mb(e));return a},zc=[],Ac={},Bc=a=>{var b=Ac[a];return void 0===b?L(a):b},Cc=()=>{function a(b){b.$$$embind_global$$$=b;var c="object"==typeof $$$embind_global$$$&&b.$$$embind_global$$$==b;c||delete b.$$$embind_global$$$;return c}if("object"==typeof globalThis)return globalThis;if("object"==typeof $$$embind_global$$$)return $$$embind_global$$$;
"object"==typeof global&&a(global)?$$$embind_global$$$=global:"object"==typeof self&&a(self)&&($$$embind_global$$$=self);if("object"==typeof $$$embind_global$$$)return $$$embind_global$$$;throw Error("unable to get global object.");},Dc=a=>{var b=zc.length;zc.push(a);return b},Ec=(a,b)=>{for(var c=Array(a),e=0;e<a;++e)c[e]=oc(G[b+4*e>>2],"parameter "+e);return c},Fc=Reflect.construct,R,Gc=a=>{var b=a.getExtension("ANGLE_instanced_arrays");b&&(a.vertexAttribDivisor=(c,e)=>b.vertexAttribDivisorANGLE(c,
e),a.drawArraysInstanced=(c,e,f,h)=>b.drawArraysInstancedANGLE(c,e,f,h),a.drawElementsInstanced=(c,e,f,h,l)=>b.drawElementsInstancedANGLE(c,e,f,h,l))},Hc=a=>{var b=a.getExtension("OES_vertex_array_object");b&&(a.createVertexArray=()=>b.createVertexArrayOES(),a.deleteVertexArray=c=>b.deleteVertexArrayOES(c),a.bindVertexArray=c=>b.bindVertexArrayOES(c),a.isVertexArray=c=>b.isVertexArrayOES(c))},Ic=a=>{var b=a.getExtension("WEBGL_draw_buffers");b&&(a.drawBuffers=(c,e)=>b.drawBuffersWEBGL(c,e))},Jc=a=>
{var b="ANGLE_instanced_arrays EXT_blend_minmax EXT_disjoint_timer_query EXT_frag_depth EXT_shader_texture_lod EXT_sRGB OES_element_index_uint OES_fbo_render_mipmap OES_standard_derivatives OES_texture_float OES_texture_half_float OES_texture_half_float_linear OES_vertex_array_object WEBGL_color_buffer_float WEBGL_depth_texture WEBGL_draw_buffers EXT_color_buffer_float EXT_conservative_depth EXT_disjoint_timer_query_webgl2 EXT_texture_norm16 NV_shader_noperspective_interpolation WEBGL_clip_cull_distance EXT_clip_control EXT_color_buffer_half_float EXT_depth_clamp EXT_float_blend EXT_polygon_offset_clamp EXT_texture_compression_bptc EXT_texture_compression_rgtc EXT_texture_filter_anisotropic KHR_parallel_shader_compile OES_texture_float_linear WEBGL_blend_func_extended WEBGL_compressed_texture_astc WEBGL_compressed_texture_etc WEBGL_compressed_texture_etc1 WEBGL_compressed_texture_s3tc WEBGL_compressed_texture_s3tc_srgb WEBGL_debug_renderer_info WEBGL_debug_shaders WEBGL_lose_context WEBGL_multi_draw WEBGL_polygon_mode".split(" ");
return(a.getSupportedExtensions()||[]).filter(c=>b.includes(c))},Kc=1,Lc=[],Mc=[],Nc=[],Oc=[],ka=[],Pc=[],Qc=[],pa=[],Rc=[],Sc=[],Tc=[],Uc={},Vc={},Xc=4,Yc=0,ja=a=>{for(var b=Kc++,c=a.length;c<b;c++)a[c]=null;return b},Zc=(a,b,c,e)=>{for(var f=0;f<a;f++){var h=R[c](),l=h&&ja(e);h?(h.name=l,e[l]=h):S||=1282;D[b+4*f>>2]=l}},la=(a,b)=>{a.Ge||(a.Ge=a.getContext,a.getContext=function(e,f){f=a.Ge(e,f);return"webgl"==e==f instanceof WebGLRenderingContext?f:null});var c=1<b.majorVersion?a.getContext("webgl2",
b):a.getContext("webgl",b);return c?$c(c,b):0},$c=(a,b)=>{var c=ja(pa),e={handle:c,attributes:b,version:b.majorVersion,ce:a};a.canvas&&(a.canvas.Oe=e);pa[c]=e;("undefined"==typeof b.Xe||b.Xe)&&ad(e);return c},oa=a=>{z=pa[a];q.nf=R=z?.ce;return!(a&&!R)},ad=a=>{a||=z;if(!a.ef){a.ef=!0;var b=a.ce;b.sf=b.getExtension("WEBGL_multi_draw");b.qf=b.getExtension("EXT_polygon_offset_clamp");b.pf=b.getExtension("EXT_clip_control");b.uf=b.getExtension("WEBGL_polygon_mode");Gc(b);Hc(b);Ic(b);b.Ie=b.getExtension("WEBGL_draw_instanced_base_vertex_base_instance");
b.Ke=b.getExtension("WEBGL_multi_draw_instanced_base_vertex_base_instance");2<=a.version&&(b.de=b.getExtension("EXT_disjoint_timer_query_webgl2"));if(2>a.version||!b.de)b.de=b.getExtension("EXT_disjoint_timer_query");Jc(b).forEach(c=>{c.includes("lose_context")||c.includes("debug")||b.getExtension(c)})}},z,S,bd=(a,b)=>{R.bindFramebuffer(a,Nc[b])},cd=a=>{R.bindVertexArray(Qc[a])},dd=a=>R.clear(a),ed=(a,b,c,e)=>R.clearColor(a,b,c,e),fd=a=>R.clearStencil(a),gd=(a,b)=>{for(var c=0;c<a;c++){var e=D[b+
4*c>>2];R.deleteVertexArray(Qc[e]);Qc[e]=null}},hd=[],jd=(a,b)=>{Zc(a,b,"createVertexArray",Qc)};function kd(){var a=Jc(R);return a=a.concat(a.map(b=>"GL_"+b))}
var ld=(a,b,c)=>{if(b){var e=void 0;switch(a){case 36346:e=1;break;case 36344:0!=c&&1!=c&&(S||=1280);return;case 34814:case 36345:e=0;break;case 34466:var f=R.getParameter(34467);e=f?f.length:0;break;case 33309:if(2>z.version){S||=1282;return}e=kd().length;break;case 33307:case 33308:if(2>z.version){S||=1280;return}e=33307==a?3:0}if(void 0===e)switch(f=R.getParameter(a),typeof f){case "number":e=f;break;case "boolean":e=f?1:0;break;case "string":S||=1280;return;case "object":if(null===f)switch(a){case 34964:case 35725:case 34965:case 36006:case 36007:case 32873:case 34229:case 36662:case 36663:case 35053:case 35055:case 36010:case 35097:case 35869:case 32874:case 36389:case 35983:case 35368:case 34068:e=
0;break;default:S||=1280;return}else{if(f instanceof Float32Array||f instanceof Uint32Array||f instanceof Int32Array||f instanceof Array){for(a=0;a<f.length;++a)switch(c){case 0:D[b+4*a>>2]=f[a];break;case 2:J[b+4*a>>2]=f[a];break;case 4:Ca[b+a]=f[a]?1:0}return}try{e=f.name|0}catch(h){S||=1280;ya(`GL_INVALID_ENUM in glGet${c}v: Unknown object returned from WebGL getParameter(${a})! (error: ${h})`);return}}break;default:S||=1280;ya(`GL_INVALID_ENUM in glGet${c}v: Native code calling glGet${c}v(${a}) and it returns ${f} of type ${typeof f}!`);
return}switch(c){case 1:c=e;G[b>>2]=c;G[b+4>>2]=(c-G[b>>2])/4294967296;break;case 0:D[b>>2]=e;break;case 2:J[b>>2]=e;break;case 4:Ca[b]=e?1:0}}else S||=1281},md=(a,b)=>ld(a,b,0),nd=(a,b,c)=>{if(c){a=Rc[a];b=2>z.version?R.de.getQueryObjectEXT(a,b):R.getQueryParameter(a,b);var e;"boolean"==typeof b?e=b?1:0:e=b;G[c>>2]=e;G[c+4>>2]=(e-G[c>>2])/4294967296}else S||=1281},pd=a=>{var b=qa(a)+1,c=od(b);c&&ra(a,c,b);return c},qd=a=>{var b=Uc[a];if(!b){switch(a){case 7939:b=pd(kd().join(" "));break;case 7936:case 7937:case 37445:case 37446:(b=
R.getParameter(a))||(S||=1280);b=b?pd(b):0;break;case 7938:b=R.getParameter(7938);var c=`OpenGL ES 2.0 (${b})`;2<=z.version&&(c=`OpenGL ES 3.0 (${b})`);b=pd(c);break;case 35724:b=R.getParameter(35724);c=b.match(/^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/);null!==c&&(3==c[1].length&&(c[1]+="0"),b=`OpenGL ES GLSL ES ${c[1]} (${b})`);b=pd(b);break;default:S||=1280}Uc[a]=b}return b},rd=(a,b)=>{if(2>z.version)return S||=1282,0;var c=Vc[a];if(c)return 0>b||b>=c.length?(S||=1281,0):c[b];switch(a){case 7939:return c=
kd().map(pd),c=Vc[a]=c,0>b||b>=c.length?(S||=1281,0):c[b];default:return S||=1280,0}},sd=a=>"]"==a.slice(-1)&&a.lastIndexOf("["),td=a=>{a-=5120;return 0==a?Ca:1==a?A:2==a?Da:4==a?D:6==a?J:5==a||28922==a||28520==a||30779==a||30782==a?G:Ea},ud=(a,b,c,e,f)=>{a=td(a);b=e*((Yc||c)*({5:3,6:4,8:2,29502:3,29504:4,26917:2,26918:2,29846:3,29847:4}[b-6402]||1)*a.BYTES_PER_ELEMENT+Xc-1&-Xc);return a.subarray(f>>>31-Math.clz32(a.BYTES_PER_ELEMENT),f+b>>>31-Math.clz32(a.BYTES_PER_ELEMENT))},W=a=>{var b=R.Ve;if(b){var c=
b.oe[a];"number"==typeof c&&(b.oe[a]=c=R.getUniformLocation(b,b.Me[a]+(0<c?`[${c}]`:"")));return c}S||=1282},vd=[],wd=[],xd={},zd=()=>{if(!yd){var a={USER:"web_user",LOGNAME:"web_user",PATH:"/",PWD:"/",HOME:"/home/web_user",LANG:("object"==typeof navigator&&navigator.languages&&navigator.languages[0]||"C").replace("-","_")+".UTF-8",_:"./this.program"},b;for(b in xd)void 0===xd[b]?delete a[b]:a[b]=xd[b];var c=[];for(b in a)c.push(`${b}=${a[b]}`);yd=c}return yd},yd,Ad=[null,[],[]];
ib=q.InternalError=class extends Error{constructor(a){super(a);this.name="InternalError"}};for(var Bd=Array(256),Cd=0;256>Cd;++Cd)Bd[Cd]=String.fromCharCode(Cd);lb=Bd;M=q.BindingError=class extends Error{constructor(a){super(a);this.name="BindingError"}};
Object.assign(Cb.prototype,{isAliasOf:function(a){if(!(this instanceof Cb&&a instanceof Cb))return!1;var b=this.Pd.Vd.Td,c=this.Pd.Sd;a.Pd=a.Pd;var e=a.Pd.Vd.Td;for(a=a.Pd.Sd;b.Yd;)c=b.pe(c),b=b.Yd;for(;e.Yd;)a=e.pe(a),e=e.Yd;return b===e&&c===a},clone:function(){this.Pd.Sd||nb(this);if(this.Pd.ne)return this.Pd.count.value+=1,this;var a=zb,b=Object,c=b.create,e=Object.getPrototypeOf(this),f=this.Pd;a=a(c.call(b,e,{Pd:{value:{count:f.count,me:f.me,ne:f.ne,Sd:f.Sd,Vd:f.Vd,Wd:f.Wd,$d:f.$d}}}));a.Pd.count.value+=
1;a.Pd.me=!1;return a},["delete"](){this.Pd.Sd||nb(this);if(this.Pd.me&&!this.Pd.ne)throw new M("Object already scheduled for deletion");pb(this);var a=this.Pd;--a.count.value;0===a.count.value&&(a.Wd?a.$d.ee(a.Wd):a.Vd.Td.ee(a.Sd));this.Pd.ne||(this.Pd.Wd=void 0,this.Pd.Sd=void 0)},isDeleted:function(){return!this.Pd.Sd},deleteLater:function(){this.Pd.Sd||nb(this);if(this.Pd.me&&!this.Pd.ne)throw new M("Object already scheduled for deletion");Bb.push(this);this.Pd.me=!0;return this}});
Object.assign(Ob.prototype,{$e(a){this.Le&&(a=this.Le(a));return a},He(a){this.ee?.(a)},ae:8,readValueFromPointer:eb,fromWireType:function(a){function b(){return this.we?Ab(this.Td.je,{Vd:this.ff,Sd:c,$d:this,Wd:a}):Ab(this.Td.je,{Vd:this,Sd:a})}var c=this.$e(a);if(!c)return this.He(a),null;var e=tb(this.Td,c);if(void 0!==e){if(0===e.Pd.count.value)return e.Pd.Sd=c,e.Pd.Wd=a,e.clone();e=e.clone();this.He(a);return e}e=this.Td.Ze(c);e=rb[e];if(!e)return b.call(this);e=this.ve?e.Ue:e.pointerType;var f=
qb(c,this.Td,e.Td);return null===f?b.call(this):this.we?Ab(e.Td.je,{Vd:e,Sd:f,$d:this,Wd:a}):Ab(e.Td.je,{Vd:e,Sd:f})}});Tb=q.UnboundTypeError=((a,b)=>{var c=Db(b,function(e){this.name=b;this.message=e;e=Error(e).stack;void 0!==e&&(this.stack=this.toString()+"\n"+e.replace(/^Error(:[^\n]*)?\n/,""))});c.prototype=Object.create(a.prototype);c.prototype.constructor=c;c.prototype.toString=function(){return void 0===this.message?this.name:`${this.name}: ${this.message}`};return c})(Error,"UnboundTypeError");
jc.push(0,1,void 0,1,null,1,!0,1,!1,1);q.count_emval_handles=()=>jc.length/2-5-ic.length;for(var Dd=0;32>Dd;++Dd)hd.push(Array(Dd));var Ed=new Float32Array(288);for(Dd=0;288>=Dd;++Dd)vd[Dd]=Ed.subarray(0,Dd);var Fd=new Int32Array(288);for(Dd=0;288>=Dd;++Dd)wd[Dd]=Fd.subarray(0,Dd);
var Sd={E:(a,b,c)=>{var e=new Wa(a);G[e.Sd+16>>2]=0;G[e.Sd+4>>2]=b;G[e.Sd+8>>2]=c;Xa=a;Ya++;throw Xa;},T:function(){return 0},rd:()=>{},qd:function(){return 0},pd:()=>{},od:function(){},nd:()=>{},jd:()=>{Pa("")},y:a=>{var b=cb[a];delete cb[a];var c=b.Ee,e=b.ee,f=b.Je,h=f.map(l=>l.cf).concat(f.map(l=>l.kf));kb([a],h,l=>{var p={};f.forEach((t,v)=>{var y=l[v],C=t.af,H=t.bf,I=l[v+f.length],Q=t.jf,P=t.lf;p[t.Ye]={read:aa=>y.fromWireType(C(H,aa)),write:(aa,ma)=>{var Y=[];Q(P,aa,I.toWireType(Y,ma));db(Y)}}});
return[{name:b.name,fromWireType:t=>{var v={},y;for(y in p)v[y]=p[y].read(t);e(t);return v},toWireType:(t,v)=>{for(var y in p)if(!(y in v))throw new TypeError(`Missing field: "${y}"`);var C=c();for(y in p)p[y].write(C,v[y]);null!==t&&t.push(e,C);return C},ae:8,readValueFromPointer:eb,be:e}]})},W:()=>{},id:(a,b,c,e)=>{b=L(b);jb(a,{name:b,fromWireType:function(f){return!!f},toWireType:function(f,h){return h?c:e},ae:8,readValueFromPointer:function(f){return this.fromWireType(A[f])},be:null})},j:(a,b,
c,e,f,h,l,p,t,v,y,C,H)=>{y=L(y);h=O(f,h);p&&=O(l,p);v&&=O(t,v);H=O(C,H);var I=Gb(y);Fb(I,function(){dc(`Cannot construct ${y} due to unbound types`,[e])});kb([a,b,c],e?[e]:[],Q=>{Q=Q[0];if(e){var P=Q.Td;var aa=P.je}else aa=Cb.prototype;Q=Db(y,function(...Fa){if(Object.getPrototypeOf(this)!==ma)throw new M("Use 'new' to construct "+y);if(void 0===Y.ge)throw new M(y+" has no accessible constructor");var ba=Y.ge[Fa.length];if(void 0===ba)throw new M(`Tried to invoke ctor of ${y} with invalid number of parameters (${Fa.length}) - expected (${Object.keys(Y.ge).toString()}) parameters instead!`);
return ba.apply(this,Fa)});var ma=Object.create(aa,{constructor:{value:Q}});Q.prototype=ma;var Y=new Hb(y,Q,ma,H,P,h,p,v);if(Y.Yd){var ea;(ea=Y.Yd).qe??(ea.qe=[]);Y.Yd.qe.push(Y)}P=new Ob(y,Y,!0,!1,!1);ea=new Ob(y+"*",Y,!1,!1,!1);aa=new Ob(y+" const*",Y,!1,!0,!1);rb[a]={pointerType:ea,Ue:aa};Pb(I,Q);return[P,ea,aa]})},e:(a,b,c,e,f,h,l)=>{var p=gc(c,e);b=L(b);b=hc(b);h=O(f,h);kb([],[a],t=>{function v(){dc(`Cannot call ${y} due to unbound types`,p)}t=t[0];var y=`${t.name}.${b}`;b.startsWith("@@")&&
(b=Symbol[b.substring(2)]);var C=t.Td.constructor;void 0===C[b]?(v.fe=c-1,C[b]=v):(Eb(C,b,y),C[b].Xd[c-1]=v);kb([],p,H=>{H=[H[0],null].concat(H.slice(1));H=fc(y,H,null,h,l);void 0===C[b].Xd?(H.fe=c-1,C[b]=H):C[b].Xd[c-1]=H;if(t.Td.qe)for(const I of t.Td.qe)I.constructor.hasOwnProperty(b)||(I.constructor[b]=H);return[]});return[]})},s:(a,b,c,e,f,h)=>{var l=gc(b,c);f=O(e,f);kb([],[a],p=>{p=p[0];var t=`constructor ${p.name}`;void 0===p.Td.ge&&(p.Td.ge=[]);if(void 0!==p.Td.ge[b-1])throw new M(`Cannot register multiple constructors with identical number of parameters (${b-
1}) for class '${p.name}'! Overload resolution is currently only performed using the parameter count, not actual type info!`);p.Td.ge[b-1]=()=>{dc(`Cannot construct ${p.name} due to unbound types`,l)};kb([],l,v=>{v.splice(1,0,null);p.Td.ge[b-1]=fc(t,v,null,f,h);return[]});return[]})},a:(a,b,c,e,f,h,l,p)=>{var t=gc(c,e);b=L(b);b=hc(b);h=O(f,h);kb([],[a],v=>{function y(){dc(`Cannot call ${C} due to unbound types`,t)}v=v[0];var C=`${v.name}.${b}`;b.startsWith("@@")&&(b=Symbol[b.substring(2)]);p&&v.Td.gf.push(b);
var H=v.Td.je,I=H[b];void 0===I||void 0===I.Xd&&I.className!==v.name&&I.fe===c-2?(y.fe=c-2,y.className=v.name,H[b]=y):(Eb(H,b,C),H[b].Xd[c-2]=y);kb([],t,Q=>{Q=fc(C,Q,v,h,l);void 0===H[b].Xd?(Q.fe=c-2,H[b]=Q):H[b].Xd[c-2]=Q;return[]});return[]})},o:(a,b,c)=>{a=L(a);kb([],[b],e=>{e=e[0];q[a]=e.fromWireType(c);return[]})},hd:a=>jb(a,mc),i:(a,b,c,e)=>{function f(){}b=L(b);f.values={};jb(a,{name:b,constructor:f,fromWireType:function(h){return this.constructor.values[h]},toWireType:(h,l)=>l.value,ae:8,
readValueFromPointer:nc(b,c,e),be:null});Fb(b,f)},b:(a,b,c)=>{var e=oc(a,"enum");b=L(b);a=e.constructor;e=Object.create(e.constructor.prototype,{value:{value:c},constructor:{value:Db(`${e.name}_${b}`,function(){})}});a.values[c]=e;a[b]=e},Q:(a,b,c)=>{b=L(b);jb(a,{name:b,fromWireType:e=>e,toWireType:(e,f)=>f,ae:8,readValueFromPointer:pc(b,c),be:null})},q:(a,b,c,e,f,h)=>{var l=gc(b,c);a=L(a);a=hc(a);f=O(e,f);Fb(a,function(){dc(`Cannot call ${a} due to unbound types`,l)},b-1);kb([],l,p=>{p=[p[0],null].concat(p.slice(1));
Pb(a,fc(a,p,null,f,h),b-1);return[]})},z:(a,b,c,e,f)=>{b=L(b);-1===f&&(f=4294967295);f=p=>p;if(0===e){var h=32-8*c;f=p=>p<<h>>>h}var l=b.includes("unsigned")?function(p,t){return t>>>0}:function(p,t){return t};jb(a,{name:b,fromWireType:f,toWireType:l,ae:8,readValueFromPointer:qc(b,c,0!==e),be:null})},n:(a,b,c)=>{function e(h){return new f(Ca.buffer,G[h+4>>2],G[h>>2])}var f=[Int8Array,Uint8Array,Int16Array,Uint16Array,Int32Array,Uint32Array,Float32Array,Float64Array][b];c=L(c);jb(a,{name:c,fromWireType:e,
ae:8,readValueFromPointer:e},{df:!0})},m:(a,b,c,e,f,h,l,p,t,v,y,C)=>{c=L(c);h=O(f,h);p=O(l,p);v=O(t,v);C=O(y,C);kb([a],[b],H=>{H=H[0];return[new Ob(c,H.Td,!1,!1,!0,H,e,h,p,v,C)]})},P:(a,b)=>{b=L(b);var c="std::string"===b;jb(a,{name:b,fromWireType:function(e){var f=G[e>>2],h=e+4;if(c)for(var l=h,p=0;p<=f;++p){var t=h+p;if(p==f||0==A[t]){l=l?$a(A,l,t-l):"";if(void 0===v)var v=l;else v+=String.fromCharCode(0),v+=l;l=t+1}}else{v=Array(f);for(p=0;p<f;++p)v[p]=String.fromCharCode(A[h+p]);v=v.join("")}bc(e);
return v},toWireType:function(e,f){f instanceof ArrayBuffer&&(f=new Uint8Array(f));var h="string"==typeof f;if(!(h||f instanceof Uint8Array||f instanceof Uint8ClampedArray||f instanceof Int8Array))throw new M("Cannot pass non-string to std::string");var l=c&&h?qa(f):f.length;var p=od(4+l+1),t=p+4;G[p>>2]=l;if(c&&h)ra(f,t,l+1);else if(h)for(h=0;h<l;++h){var v=f.charCodeAt(h);if(255<v)throw bc(t),new M("String has UTF-16 code units that do not fit in 8 bits");A[t+h]=v}else for(h=0;h<l;++h)A[t+h]=f[h];
null!==e&&e.push(bc,p);return p},ae:8,readValueFromPointer:eb,be(e){bc(e)}})},L:(a,b,c)=>{c=L(c);if(2===b){var e=sc;var f=tc;var h=uc;var l=p=>Ea[p>>1]}else 4===b&&(e=vc,f=wc,h=xc,l=p=>G[p>>2]);jb(a,{name:c,fromWireType:p=>{for(var t=G[p>>2],v,y=p+4,C=0;C<=t;++C){var H=p+4+C*b;if(C==t||0==l(H))y=e(y,H-y),void 0===v?v=y:(v+=String.fromCharCode(0),v+=y),y=H+b}bc(p);return v},toWireType:(p,t)=>{if("string"!=typeof t)throw new M(`Cannot pass non-string to C++ string type ${c}`);var v=h(t),y=od(4+v+b);
G[y>>2]=v/b;f(t,y+4,v+b);null!==p&&p.push(bc,y);return y},ae:8,readValueFromPointer:eb,be(p){bc(p)}})},x:(a,b,c,e,f,h)=>{cb[a]={name:L(b),Ee:O(c,e),ee:O(f,h),Je:[]}},d:(a,b,c,e,f,h,l,p,t,v)=>{cb[a].Je.push({Ye:L(b),cf:c,af:O(e,f),bf:h,kf:l,jf:O(p,t),lf:v})},gd:(a,b)=>{b=L(b);jb(a,{rf:!0,name:b,ae:0,fromWireType:()=>{},toWireType:()=>{}})},fd:()=>1,ed:()=>{throw Infinity;},D:(a,b,c)=>{a=lc(a);b=oc(b,"emval::as");return yc(b,c,a)},K:(a,b,c,e)=>{a=zc[a];b=lc(b);return a(null,b,c,e)},p:(a,b,c,e,f)=>{a=
zc[a];b=lc(b);c=Bc(c);return a(b,b[c],e,f)},c:kc,J:a=>{if(0===a)return Mb(Cc());a=Bc(a);return Mb(Cc()[a])},l:(a,b,c)=>{var e=Ec(a,b),f=e.shift();a--;var h=Array(a);b=`methodCaller<(${e.map(l=>l.name).join(", ")}) => ${f.name}>`;return Dc(Db(b,(l,p,t,v)=>{for(var y=0,C=0;C<a;++C)h[C]=e[C].readValueFromPointer(v+y),y+=e[C].ae;l=1===c?Fc(p,h):p.apply(l,h);return yc(f,t,l)}))},t:(a,b)=>{a=lc(a);b=lc(b);return Mb(a[b])},H:a=>{9<a&&(jc[a+1]+=1)},G:()=>Mb([]),f:a=>Mb(Bc(a)),C:()=>Mb({}),dd:a=>{a=lc(a);
return!a},k:a=>{var b=lc(a);db(b);kc(a)},h:(a,b,c)=>{a=lc(a);b=lc(b);c=lc(c);a[b]=c},g:(a,b)=>{a=oc(a,"_emval_take_value");a=a.readValueFromPointer(b);return Mb(a)},V:function(){return-52},U:function(){},cd:(a,b,c,e)=>{var f=(new Date).getFullYear(),h=(new Date(f,0,1)).getTimezoneOffset();f=(new Date(f,6,1)).getTimezoneOffset();G[a>>2]=60*Math.max(h,f);D[b>>2]=Number(h!=f);b=l=>{var p=Math.abs(l);return`UTC${0<=l?"-":"+"}${String(Math.floor(p/60)).padStart(2,"0")}${String(p%60).padStart(2,"0")}`};
a=b(h);b=b(f);f<h?(ra(a,c,17),ra(b,e,17)):(ra(a,e,17),ra(b,c,17))},bd:()=>performance.now(),ad:a=>R.activeTexture(a),$c:(a,b)=>{R.attachShader(Mc[a],Pc[b])},_c:(a,b)=>{R.beginQuery(a,Rc[b])},Zc:(a,b)=>{R.de.beginQueryEXT(a,Rc[b])},Yc:(a,b,c)=>{R.bindAttribLocation(Mc[a],b,c?$a(A,c):"")},Xc:(a,b)=>{35051==a?R.Be=b:35052==a&&(R.ie=b);R.bindBuffer(a,Lc[b])},Wc:bd,Vc:(a,b)=>{R.bindRenderbuffer(a,Oc[b])},Uc:(a,b)=>{R.bindSampler(a,Sc[b])},Tc:(a,b)=>{R.bindTexture(a,ka[b])},Sc:cd,Rc:cd,Qc:(a,b,c,e)=>R.blendColor(a,
b,c,e),Pc:a=>R.blendEquation(a),Oc:(a,b)=>R.blendFunc(a,b),Nc:(a,b,c,e,f,h,l,p,t,v)=>R.blitFramebuffer(a,b,c,e,f,h,l,p,t,v),Mc:(a,b,c,e)=>{2<=z.version?c&&b?R.bufferData(a,A,e,c,b):R.bufferData(a,b,e):R.bufferData(a,c?A.subarray(c,c+b):b,e)},Lc:(a,b,c,e)=>{2<=z.version?c&&R.bufferSubData(a,b,A,e,c):R.bufferSubData(a,b,A.subarray(e,e+c))},Kc:a=>R.checkFramebufferStatus(a),Jc:dd,Ic:ed,Hc:fd,Gc:(a,b,c,e)=>R.clientWaitSync(Tc[a],b,(c>>>0)+4294967296*e),Fc:(a,b,c,e)=>{R.colorMask(!!a,!!b,!!c,!!e)},Ec:a=>
{R.compileShader(Pc[a])},Dc:(a,b,c,e,f,h,l,p)=>{2<=z.version?R.ie||!l?R.compressedTexImage2D(a,b,c,e,f,h,l,p):R.compressedTexImage2D(a,b,c,e,f,h,A,p,l):R.compressedTexImage2D(a,b,c,e,f,h,A.subarray(p,p+l))},Cc:(a,b,c,e,f,h,l,p,t)=>{2<=z.version?R.ie||!p?R.compressedTexSubImage2D(a,b,c,e,f,h,l,p,t):R.compressedTexSubImage2D(a,b,c,e,f,h,l,A,t,p):R.compressedTexSubImage2D(a,b,c,e,f,h,l,A.subarray(t,t+p))},Bc:(a,b,c,e,f)=>R.copyBufferSubData(a,b,c,e,f),Ac:(a,b,c,e,f,h,l,p)=>R.copyTexSubImage2D(a,b,c,
e,f,h,l,p),zc:()=>{var a=ja(Mc),b=R.createProgram();b.name=a;b.ze=b.xe=b.ye=0;b.Fe=1;Mc[a]=b;return a},yc:a=>{var b=ja(Pc);Pc[b]=R.createShader(a);return b},xc:a=>R.cullFace(a),wc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Lc[e];f&&(R.deleteBuffer(f),f.name=0,Lc[e]=null,e==R.Be&&(R.Be=0),e==R.ie&&(R.ie=0))}},vc:(a,b)=>{for(var c=0;c<a;++c){var e=D[b+4*c>>2],f=Nc[e];f&&(R.deleteFramebuffer(f),f.name=0,Nc[e]=null)}},uc:a=>{if(a){var b=Mc[a];b?(R.deleteProgram(b),b.name=0,Mc[a]=null):S||=1281}},
tc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Rc[e];f&&(R.deleteQuery(f),Rc[e]=null)}},sc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Rc[e];f&&(R.de.deleteQueryEXT(f),Rc[e]=null)}},rc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Oc[e];f&&(R.deleteRenderbuffer(f),f.name=0,Oc[e]=null)}},qc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=Sc[e];f&&(R.deleteSampler(f),f.name=0,Sc[e]=null)}},pc:a=>{if(a){var b=Pc[a];b?(R.deleteShader(b),Pc[a]=null):S||=1281}},oc:a=>{if(a){var b=Tc[a];b?
(R.deleteSync(b),b.name=0,Tc[a]=null):S||=1281}},nc:(a,b)=>{for(var c=0;c<a;c++){var e=D[b+4*c>>2],f=ka[e];f&&(R.deleteTexture(f),f.name=0,ka[e]=null)}},mc:gd,lc:gd,kc:a=>{R.depthMask(!!a)},jc:a=>R.disable(a),ic:a=>{R.disableVertexAttribArray(a)},hc:(a,b,c)=>{R.drawArrays(a,b,c)},gc:(a,b,c,e)=>{R.drawArraysInstanced(a,b,c,e)},fc:(a,b,c,e,f)=>{R.Ie.drawArraysInstancedBaseInstanceWEBGL(a,b,c,e,f)},ec:(a,b)=>{for(var c=hd[a],e=0;e<a;e++)c[e]=D[b+4*e>>2];R.drawBuffers(c)},dc:(a,b,c,e)=>{R.drawElements(a,
b,c,e)},cc:(a,b,c,e,f)=>{R.drawElementsInstanced(a,b,c,e,f)},bc:(a,b,c,e,f,h,l)=>{R.Ie.drawElementsInstancedBaseVertexBaseInstanceWEBGL(a,b,c,e,f,h,l)},ac:(a,b,c,e,f,h)=>{R.drawElements(a,e,f,h)},$b:a=>R.enable(a),_b:a=>{R.enableVertexAttribArray(a)},Zb:a=>R.endQuery(a),Yb:a=>{R.de.endQueryEXT(a)},Xb:(a,b)=>(a=R.fenceSync(a,b))?(b=ja(Tc),a.name=b,Tc[b]=a,b):0,Wb:()=>R.finish(),Vb:()=>R.flush(),Ub:(a,b,c,e)=>{R.framebufferRenderbuffer(a,b,c,Oc[e])},Tb:(a,b,c,e,f)=>{R.framebufferTexture2D(a,b,c,ka[e],
f)},Sb:a=>R.frontFace(a),Rb:(a,b)=>{Zc(a,b,"createBuffer",Lc)},Qb:(a,b)=>{Zc(a,b,"createFramebuffer",Nc)},Pb:(a,b)=>{Zc(a,b,"createQuery",Rc)},Ob:(a,b)=>{for(var c=0;c<a;c++){var e=R.de.createQueryEXT();if(!e){for(S||=1282;c<a;)D[b+4*c++>>2]=0;break}var f=ja(Rc);e.name=f;Rc[f]=e;D[b+4*c>>2]=f}},Nb:(a,b)=>{Zc(a,b,"createRenderbuffer",Oc)},Mb:(a,b)=>{Zc(a,b,"createSampler",Sc)},Lb:(a,b)=>{Zc(a,b,"createTexture",ka)},Kb:jd,Jb:jd,Ib:a=>R.generateMipmap(a),Hb:(a,b,c)=>{c?D[c>>2]=R.getBufferParameter(a,
b):S||=1281},Gb:()=>{var a=R.getError()||S;S=0;return a},Fb:(a,b)=>ld(a,b,2),Eb:(a,b,c,e)=>{a=R.getFramebufferAttachmentParameter(a,b,c);if(a instanceof WebGLRenderbuffer||a instanceof WebGLTexture)a=a.name|0;D[e>>2]=a},Db:md,Cb:(a,b,c,e)=>{a=R.getProgramInfoLog(Mc[a]);null===a&&(a="(unknown error)");b=0<b&&e?ra(a,e,b):0;c&&(D[c>>2]=b)},Bb:(a,b,c)=>{if(c)if(a>=Kc)S||=1281;else if(a=Mc[a],35716==b)a=R.getProgramInfoLog(a),null===a&&(a="(unknown error)"),D[c>>2]=a.length+1;else if(35719==b){if(!a.ze){var e=
R.getProgramParameter(a,35718);for(b=0;b<e;++b)a.ze=Math.max(a.ze,R.getActiveUniform(a,b).name.length+1)}D[c>>2]=a.ze}else if(35722==b){if(!a.xe)for(e=R.getProgramParameter(a,35721),b=0;b<e;++b)a.xe=Math.max(a.xe,R.getActiveAttrib(a,b).name.length+1);D[c>>2]=a.xe}else if(35381==b){if(!a.ye)for(e=R.getProgramParameter(a,35382),b=0;b<e;++b)a.ye=Math.max(a.ye,R.getActiveUniformBlockName(a,b).length+1);D[c>>2]=a.ye}else D[c>>2]=R.getProgramParameter(a,b);else S||=1281},Ab:nd,zb:nd,yb:(a,b,c)=>{if(c){a=
R.getQueryParameter(Rc[a],b);var e;"boolean"==typeof a?e=a?1:0:e=a;D[c>>2]=e}else S||=1281},xb:(a,b,c)=>{if(c){a=R.de.getQueryObjectEXT(Rc[a],b);var e;"boolean"==typeof a?e=a?1:0:e=a;D[c>>2]=e}else S||=1281},wb:(a,b,c)=>{c?D[c>>2]=R.getQuery(a,b):S||=1281},vb:(a,b,c)=>{c?D[c>>2]=R.de.getQueryEXT(a,b):S||=1281},ub:(a,b,c)=>{c?D[c>>2]=R.getRenderbufferParameter(a,b):S||=1281},tb:(a,b,c,e)=>{a=R.getShaderInfoLog(Pc[a]);null===a&&(a="(unknown error)");b=0<b&&e?ra(a,e,b):0;c&&(D[c>>2]=b)},sb:(a,b,c,e)=>
{a=R.getShaderPrecisionFormat(a,b);D[c>>2]=a.rangeMin;D[c+4>>2]=a.rangeMax;D[e>>2]=a.precision},rb:(a,b,c)=>{c?35716==b?(a=R.getShaderInfoLog(Pc[a]),null===a&&(a="(unknown error)"),D[c>>2]=a?a.length+1:0):35720==b?(a=R.getShaderSource(Pc[a]),D[c>>2]=a?a.length+1:0):D[c>>2]=R.getShaderParameter(Pc[a],b):S||=1281},qb:qd,pb:rd,ob:(a,b)=>{b=b?$a(A,b):"";if(a=Mc[a]){var c=a,e=c.oe,f=c.Ne,h;if(!e){c.oe=e={};c.Me={};var l=R.getProgramParameter(c,35718);for(h=0;h<l;++h){var p=R.getActiveUniform(c,h);var t=
p.name;p=p.size;var v=sd(t);v=0<v?t.slice(0,v):t;var y=c.Fe;c.Fe+=p;f[v]=[p,y];for(t=0;t<p;++t)e[y]=t,c.Me[y++]=v}}c=a.oe;e=0;f=b;h=sd(b);0<h&&(e=parseInt(b.slice(h+1))>>>0,f=b.slice(0,h));if((f=a.Ne[f])&&e<f[0]&&(e+=f[1],c[e]=c[e]||R.getUniformLocation(a,b)))return e}else S||=1281;return-1},nb:(a,b,c)=>{for(var e=hd[b],f=0;f<b;f++)e[f]=D[c+4*f>>2];R.invalidateFramebuffer(a,e)},mb:(a,b,c,e,f,h,l)=>{for(var p=hd[b],t=0;t<b;t++)p[t]=D[c+4*t>>2];R.invalidateSubFramebuffer(a,p,e,f,h,l)},lb:a=>R.isSync(Tc[a]),
kb:a=>(a=ka[a])?R.isTexture(a):0,jb:a=>R.lineWidth(a),ib:a=>{a=Mc[a];R.linkProgram(a);a.oe=0;a.Ne={}},hb:(a,b,c,e,f,h)=>{R.Ke.multiDrawArraysInstancedBaseInstanceWEBGL(a,D,b>>2,D,c>>2,D,e>>2,G,f>>2,h)},gb:(a,b,c,e,f,h,l,p)=>{R.Ke.multiDrawElementsInstancedBaseVertexBaseInstanceWEBGL(a,D,b>>2,c,D,e>>2,D,f>>2,D,h>>2,G,l>>2,p)},fb:(a,b)=>{3317==a?Xc=b:3314==a&&(Yc=b);R.pixelStorei(a,b)},eb:(a,b)=>{R.de.queryCounterEXT(Rc[a],b)},db:a=>R.readBuffer(a),cb:(a,b,c,e,f,h,l)=>{if(2<=z.version)if(R.Be)R.readPixels(a,
b,c,e,f,h,l);else{var p=td(h);l>>>=31-Math.clz32(p.BYTES_PER_ELEMENT);R.readPixels(a,b,c,e,f,h,p,l)}else(p=ud(h,f,c,e,l))?R.readPixels(a,b,c,e,f,h,p):S||=1280},bb:(a,b,c,e)=>R.renderbufferStorage(a,b,c,e),ab:(a,b,c,e,f)=>R.renderbufferStorageMultisample(a,b,c,e,f),$a:(a,b,c)=>{R.samplerParameterf(Sc[a],b,c)},_a:(a,b,c)=>{R.samplerParameteri(Sc[a],b,c)},Za:(a,b,c)=>{R.samplerParameteri(Sc[a],b,D[c>>2])},Ya:(a,b,c,e)=>R.scissor(a,b,c,e),Xa:(a,b,c,e)=>{for(var f="",h=0;h<b;++h){var l=(l=G[c+4*h>>2])?
$a(A,l,e?G[e+4*h>>2]:void 0):"";f+=l}R.shaderSource(Pc[a],f)},Wa:(a,b,c)=>R.stencilFunc(a,b,c),Va:(a,b,c,e)=>R.stencilFuncSeparate(a,b,c,e),Ua:a=>R.stencilMask(a),Ta:(a,b)=>R.stencilMaskSeparate(a,b),Sa:(a,b,c)=>R.stencilOp(a,b,c),Ra:(a,b,c,e)=>R.stencilOpSeparate(a,b,c,e),Qa:(a,b,c,e,f,h,l,p,t)=>{if(2<=z.version){if(R.ie){R.texImage2D(a,b,c,e,f,h,l,p,t);return}if(t){var v=td(p);t>>>=31-Math.clz32(v.BYTES_PER_ELEMENT);R.texImage2D(a,b,c,e,f,h,l,p,v,t);return}}v=t?ud(p,l,e,f,t):null;R.texImage2D(a,
b,c,e,f,h,l,p,v)},Pa:(a,b,c)=>R.texParameterf(a,b,c),Oa:(a,b,c)=>{R.texParameterf(a,b,J[c>>2])},Na:(a,b,c)=>R.texParameteri(a,b,c),Ma:(a,b,c)=>{R.texParameteri(a,b,D[c>>2])},La:(a,b,c,e,f)=>R.texStorage2D(a,b,c,e,f),Ka:(a,b,c,e,f,h,l,p,t)=>{if(2<=z.version){if(R.ie){R.texSubImage2D(a,b,c,e,f,h,l,p,t);return}if(t){var v=td(p);R.texSubImage2D(a,b,c,e,f,h,l,p,v,t>>>31-Math.clz32(v.BYTES_PER_ELEMENT));return}}t=t?ud(p,l,f,h,t):null;R.texSubImage2D(a,b,c,e,f,h,l,p,t)},Ja:(a,b)=>{R.uniform1f(W(a),b)},Ia:(a,
b,c)=>{if(2<=z.version)b&&R.uniform1fv(W(a),J,c>>2,b);else{if(288>=b)for(var e=vd[b],f=0;f<b;++f)e[f]=J[c+4*f>>2];else e=J.subarray(c>>2,c+4*b>>2);R.uniform1fv(W(a),e)}},Ha:(a,b)=>{R.uniform1i(W(a),b)},Ga:(a,b,c)=>{if(2<=z.version)b&&R.uniform1iv(W(a),D,c>>2,b);else{if(288>=b)for(var e=wd[b],f=0;f<b;++f)e[f]=D[c+4*f>>2];else e=D.subarray(c>>2,c+4*b>>2);R.uniform1iv(W(a),e)}},Fa:(a,b,c)=>{R.uniform2f(W(a),b,c)},Ea:(a,b,c)=>{if(2<=z.version)b&&R.uniform2fv(W(a),J,c>>2,2*b);else{if(144>=b){b*=2;for(var e=
vd[b],f=0;f<b;f+=2)e[f]=J[c+4*f>>2],e[f+1]=J[c+(4*f+4)>>2]}else e=J.subarray(c>>2,c+8*b>>2);R.uniform2fv(W(a),e)}},Da:(a,b,c)=>{R.uniform2i(W(a),b,c)},Ca:(a,b,c)=>{if(2<=z.version)b&&R.uniform2iv(W(a),D,c>>2,2*b);else{if(144>=b){b*=2;for(var e=wd[b],f=0;f<b;f+=2)e[f]=D[c+4*f>>2],e[f+1]=D[c+(4*f+4)>>2]}else e=D.subarray(c>>2,c+8*b>>2);R.uniform2iv(W(a),e)}},Ba:(a,b,c,e)=>{R.uniform3f(W(a),b,c,e)},Aa:(a,b,c)=>{if(2<=z.version)b&&R.uniform3fv(W(a),J,c>>2,3*b);else{if(96>=b){b*=3;for(var e=vd[b],f=0;f<
b;f+=3)e[f]=J[c+4*f>>2],e[f+1]=J[c+(4*f+4)>>2],e[f+2]=J[c+(4*f+8)>>2]}else e=J.subarray(c>>2,c+12*b>>2);R.uniform3fv(W(a),e)}},za:(a,b,c,e)=>{R.uniform3i(W(a),b,c,e)},ya:(a,b,c)=>{if(2<=z.version)b&&R.uniform3iv(W(a),D,c>>2,3*b);else{if(96>=b){b*=3;for(var e=wd[b],f=0;f<b;f+=3)e[f]=D[c+4*f>>2],e[f+1]=D[c+(4*f+4)>>2],e[f+2]=D[c+(4*f+8)>>2]}else e=D.subarray(c>>2,c+12*b>>2);R.uniform3iv(W(a),e)}},xa:(a,b,c,e,f)=>{R.uniform4f(W(a),b,c,e,f)},wa:(a,b,c)=>{if(2<=z.version)b&&R.uniform4fv(W(a),J,c>>2,4*
b);else{if(72>=b){var e=vd[4*b],f=J;c>>=2;b*=4;for(var h=0;h<b;h+=4){var l=c+h;e[h]=f[l];e[h+1]=f[l+1];e[h+2]=f[l+2];e[h+3]=f[l+3]}}else e=J.subarray(c>>2,c+16*b>>2);R.uniform4fv(W(a),e)}},va:(a,b,c,e,f)=>{R.uniform4i(W(a),b,c,e,f)},ua:(a,b,c)=>{if(2<=z.version)b&&R.uniform4iv(W(a),D,c>>2,4*b);else{if(72>=b){b*=4;for(var e=wd[b],f=0;f<b;f+=4)e[f]=D[c+4*f>>2],e[f+1]=D[c+(4*f+4)>>2],e[f+2]=D[c+(4*f+8)>>2],e[f+3]=D[c+(4*f+12)>>2]}else e=D.subarray(c>>2,c+16*b>>2);R.uniform4iv(W(a),e)}},ta:(a,b,c,e)=>
{if(2<=z.version)b&&R.uniformMatrix2fv(W(a),!!c,J,e>>2,4*b);else{if(72>=b){b*=4;for(var f=vd[b],h=0;h<b;h+=4)f[h]=J[e+4*h>>2],f[h+1]=J[e+(4*h+4)>>2],f[h+2]=J[e+(4*h+8)>>2],f[h+3]=J[e+(4*h+12)>>2]}else f=J.subarray(e>>2,e+16*b>>2);R.uniformMatrix2fv(W(a),!!c,f)}},sa:(a,b,c,e)=>{if(2<=z.version)b&&R.uniformMatrix3fv(W(a),!!c,J,e>>2,9*b);else{if(32>=b){b*=9;for(var f=vd[b],h=0;h<b;h+=9)f[h]=J[e+4*h>>2],f[h+1]=J[e+(4*h+4)>>2],f[h+2]=J[e+(4*h+8)>>2],f[h+3]=J[e+(4*h+12)>>2],f[h+4]=J[e+(4*h+16)>>2],f[h+
5]=J[e+(4*h+20)>>2],f[h+6]=J[e+(4*h+24)>>2],f[h+7]=J[e+(4*h+28)>>2],f[h+8]=J[e+(4*h+32)>>2]}else f=J.subarray(e>>2,e+36*b>>2);R.uniformMatrix3fv(W(a),!!c,f)}},ra:(a,b,c,e)=>{if(2<=z.version)b&&R.uniformMatrix4fv(W(a),!!c,J,e>>2,16*b);else{if(18>=b){var f=vd[16*b],h=J;e>>=2;b*=16;for(var l=0;l<b;l+=16){var p=e+l;f[l]=h[p];f[l+1]=h[p+1];f[l+2]=h[p+2];f[l+3]=h[p+3];f[l+4]=h[p+4];f[l+5]=h[p+5];f[l+6]=h[p+6];f[l+7]=h[p+7];f[l+8]=h[p+8];f[l+9]=h[p+9];f[l+10]=h[p+10];f[l+11]=h[p+11];f[l+12]=h[p+12];f[l+
13]=h[p+13];f[l+14]=h[p+14];f[l+15]=h[p+15]}}else f=J.subarray(e>>2,e+64*b>>2);R.uniformMatrix4fv(W(a),!!c,f)}},qa:a=>{a=Mc[a];R.useProgram(a);R.Ve=a},pa:(a,b)=>R.vertexAttrib1f(a,b),oa:(a,b)=>{R.vertexAttrib2f(a,J[b>>2],J[b+4>>2])},na:(a,b)=>{R.vertexAttrib3f(a,J[b>>2],J[b+4>>2],J[b+8>>2])},ma:(a,b)=>{R.vertexAttrib4f(a,J[b>>2],J[b+4>>2],J[b+8>>2],J[b+12>>2])},la:(a,b)=>{R.vertexAttribDivisor(a,b)},ka:(a,b,c,e,f)=>{R.vertexAttribIPointer(a,b,c,e,f)},ja:(a,b,c,e,f,h)=>{R.vertexAttribPointer(a,b,c,
!!e,f,h)},ia:(a,b,c,e)=>R.viewport(a,b,c,e),ha:(a,b,c,e)=>{R.waitSync(Tc[a],b,(c>>>0)+4294967296*e)},ga:a=>{var b=A.length;a>>>=0;if(2147483648<a)return!1;for(var c=1;4>=c;c*=2){var e=b*(1+1/c);e=Math.min(e,a+100663296);a:{e=(Math.min(2147483648,65536*Math.ceil(Math.max(a,e)/65536))-za.buffer.byteLength+65535)/65536|0;try{za.grow(e);Ha();var f=1;break a}catch(h){}f=void 0}if(f)return!0}return!1},fa:()=>z?z.handle:0,md:(a,b)=>{var c=0;zd().forEach((e,f)=>{var h=b+c;f=G[a+4*f>>2]=h;for(h=0;h<e.length;++h)Ca[f++]=
e.charCodeAt(h);Ca[f]=0;c+=e.length+1});return 0},ld:(a,b)=>{var c=zd();G[a>>2]=c.length;var e=0;c.forEach(f=>e+=f.length+1);G[b>>2]=e;return 0},S:()=>52,Y:function(){return 52},kd:()=>52,X:function(){return 70},R:(a,b,c,e)=>{for(var f=0,h=0;h<c;h++){var l=G[b>>2],p=G[b+4>>2];b+=8;for(var t=0;t<p;t++){var v=A[l+t],y=Ad[a];0===v||10===v?((1===a?wa:ya)($a(y)),y.length=0):y.push(v)}f+=p}G[e>>2]=f;return 0},ea:bd,da:dd,ca:ed,ba:fd,I:md,O:qd,aa:rd,w:Gd,F:Hd,v:Id,N:Jd,$:Kd,M:Ld,u:Md,r:Nd,B:Od,A:Pd,_:Qd,
Z:Rd},Z=function(){function a(c){Z=c.exports;za=Z.sd;Ha();Qb=Z.vd;Ja.unshift(Z.td);La--;0==La&&(null!==Ma&&(clearInterval(Ma),Ma=null),Oa&&(c=Oa,Oa=null,c()));return Z}var b={a:Sd};La++;if(q.instantiateWasm)try{return q.instantiateWasm(b,a)}catch(c){ya(`Module.instantiateWasm callback failed with error: ${c}`),da(c)}Ra??=q.locateFile?Qa("canvaskit.wasm")?"canvaskit.wasm":ta+"canvaskit.wasm":(new URL("canvaskit.wasm",import.meta.url)).href;Ua(b,function(c){a(c.instance)}).catch(da);return{}}(),
ac=a=>(ac=Z.ud)(a),od=q._malloc=a=>(od=q._malloc=Z.wd)(a),bc=q._free=a=>(bc=q._free=Z.xd)(a),Td=(a,b)=>(Td=Z.yd)(a,b),Ud=a=>(Ud=Z.zd)(a),Vd=()=>(Vd=Z.Ad)();q.dynCall_viji=(a,b,c,e,f)=>(q.dynCall_viji=Z.Bd)(a,b,c,e,f);q.dynCall_vijiii=(a,b,c,e,f,h,l)=>(q.dynCall_vijiii=Z.Cd)(a,b,c,e,f,h,l);q.dynCall_viiiiij=(a,b,c,e,f,h,l,p)=>(q.dynCall_viiiiij=Z.Dd)(a,b,c,e,f,h,l,p);q.dynCall_vij=(a,b,c,e)=>(q.dynCall_vij=Z.Ed)(a,b,c,e);q.dynCall_jii=(a,b,c)=>(q.dynCall_jii=Z.Fd)(a,b,c);
q.dynCall_jiiiiii=(a,b,c,e,f,h,l)=>(q.dynCall_jiiiiii=Z.Gd)(a,b,c,e,f,h,l);q.dynCall_jiiiiji=(a,b,c,e,f,h,l,p)=>(q.dynCall_jiiiiji=Z.Hd)(a,b,c,e,f,h,l,p);q.dynCall_ji=(a,b)=>(q.dynCall_ji=Z.Id)(a,b);q.dynCall_iijj=(a,b,c,e,f,h)=>(q.dynCall_iijj=Z.Jd)(a,b,c,e,f,h);q.dynCall_jiji=(a,b,c,e,f)=>(q.dynCall_jiji=Z.Kd)(a,b,c,e,f);q.dynCall_viijii=(a,b,c,e,f,h,l)=>(q.dynCall_viijii=Z.Ld)(a,b,c,e,f,h,l);q.dynCall_iiiiij=(a,b,c,e,f,h,l)=>(q.dynCall_iiiiij=Z.Md)(a,b,c,e,f,h,l);
q.dynCall_iiiiijj=(a,b,c,e,f,h,l,p,t)=>(q.dynCall_iiiiijj=Z.Nd)(a,b,c,e,f,h,l,p,t);q.dynCall_iiiiiijj=(a,b,c,e,f,h,l,p,t,v)=>(q.dynCall_iiiiiijj=Z.Od)(a,b,c,e,f,h,l,p,t,v);function Pd(a,b,c,e,f){var h=Vd();try{Qb.get(a)(b,c,e,f)}catch(l){Ud(h);if(l!==l+0)throw l;Td(1,0)}}function Hd(a,b,c){var e=Vd();try{return Qb.get(a)(b,c)}catch(f){Ud(e);if(f!==f+0)throw f;Td(1,0)}}function Nd(a,b,c){var e=Vd();try{Qb.get(a)(b,c)}catch(f){Ud(e);if(f!==f+0)throw f;Td(1,0)}}
function Gd(a,b){var c=Vd();try{return Qb.get(a)(b)}catch(e){Ud(c);if(e!==e+0)throw e;Td(1,0)}}function Md(a,b){var c=Vd();try{Qb.get(a)(b)}catch(e){Ud(c);if(e!==e+0)throw e;Td(1,0)}}function Id(a,b,c,e){var f=Vd();try{return Qb.get(a)(b,c,e)}catch(h){Ud(f);if(h!==h+0)throw h;Td(1,0)}}function Rd(a,b,c,e,f,h,l,p,t,v){var y=Vd();try{Qb.get(a)(b,c,e,f,h,l,p,t,v)}catch(C){Ud(y);if(C!==C+0)throw C;Td(1,0)}}
function Od(a,b,c,e){var f=Vd();try{Qb.get(a)(b,c,e)}catch(h){Ud(f);if(h!==h+0)throw h;Td(1,0)}}function Qd(a,b,c,e,f,h,l){var p=Vd();try{Qb.get(a)(b,c,e,f,h,l)}catch(t){Ud(p);if(t!==t+0)throw t;Td(1,0)}}function Jd(a,b,c,e,f){var h=Vd();try{return Qb.get(a)(b,c,e,f)}catch(l){Ud(h);if(l!==l+0)throw l;Td(1,0)}}function Ld(a,b,c,e,f,h,l,p,t,v){var y=Vd();try{return Qb.get(a)(b,c,e,f,h,l,p,t,v)}catch(C){Ud(y);if(C!==C+0)throw C;Td(1,0)}}
function Kd(a,b,c,e,f,h,l){var p=Vd();try{return Qb.get(a)(b,c,e,f,h,l)}catch(t){Ud(p);if(t!==t+0)throw t;Td(1,0)}}var Wd,Xd;Oa=function Yd(){Wd||Zd();Wd||(Oa=Yd)};function Zd(){if(!(0<La)){if(!Xd&&(Xd=1,Va(Ia),0<La))return;Wd||(Wd=1,q.calledRun=1,Aa||(Va(Ja),ca(q),q.onRuntimeInitialized?.(),Va(Ka)))}}Zd();moduleRtn=fa;


  return moduleRtn;
}
);
})();
export default CanvasKitInit;
